
import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def ImportSpec(vim, *args, **kwargs):
    '''An ImportSpec is used when importing VMs or vApps.It can be built from scratch,
    or it can be generated from an OVF descriptor using the service interface
    OvfManager.This class is the abstract base for VirtualMachineImportSpec and
    VirtualAppImportSpec. These three classes form a composite structure that
    allows us to contain arbitrarily complex entitites in a single ImportSpec.'''

    obj = vim.client.factory.create('{urn:vim25}ImportSpec')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 0:
        raise IndexError('Expected at least 1 arguments got: %d' % len(args))

    required = [  ]
    optional = [ 'entityConfig', 'instantiationOst', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class StorageNmpSatp(Base):
    '''
    Operations pertaining to the Storage Array Type Plugins for the VMware Native Multipath Plugin.
    '''
    moid = 'ha-cli-handler-storage-nmp-satp'
    def set(self, defaultpsp, satp, boot=None):
        '''
        Set the default Path Selection Policy for a given Storage Array Type Plugin (SATP).
        :param boot: boolean, This is a system default rule added at boot time. Do not modify esx.conf or add to host profile.
        :param defaultpsp: string, The default path selection policy to set for a given --satp 
        :param satp: string, The SATP name for the Storage Array Type Plugin on which this command will operate.
        :returns: string
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.nmp.satp.Set',
                            boot=boot,
                            defaultpsp=defaultpsp,
                            satp=satp,
                            )
    def list(self):
        '''
        List the Storage Array Type Plugins (SATP) that are currently loaded into the NMP system and display information about those SATPs
        :returns: vim.EsxCLI.storage.nmp.satp.list.StorageArrayTypePlugin[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.nmp.satp.List',
                            )   



from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class StorageCoreDevice(Base):
    '''
    Operations pertaining to the pluggable storage architectures' logical devices on the system. The operation currently allowed is to list the available devices on the system and the filters attached to each
    '''
    moid = 'ha-cli-handler-storage-core-device'
    def set(self, device, name=None, nopersist=None, state=None):
        '''
        Provide control to allow a user to modify a SCSI device's state.
        :param device: string, The device you wish to operate upon. This can be any of the UIDs that a device reports.
        :param name: string, The new name to assign the given device.
        :param nopersist: boolean, Set device state non-peristently; state is lost after reboot.
        :param state: string, Set the SCSI device state for a the specific device given. Valid values are : 
    off: Set the device's state to OFF.
    on: Set the device's state to ON.

        :returns: void
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.core.device.Set',
                            device=device,
                            name=name,
                            nopersist=nopersist,
                            state=state,
                            )
    def list(self, device=None):
        '''
        For devices currently registered with the PSA, list the filters attached to them.
        :param device: string, Filter the output of this command to only show a single device.
        :returns: vim.EsxCLI.storage.core.device.list.ScsiDevice[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.core.device.List',
                            device=device,
                            )
    def setconfig(self, device, detached=None, perenniallyreserved=None):
        '''
        Set device configuration
        :param detached: boolean, Mark device as detached.
        :param device: string, Apply the command to a single device.
        :param perenniallyreserved: boolean, Mark device as perennially reserved.
        :returns: void
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.core.device.Setconfig',
                            detached=detached,
                            device=device,
                            perenniallyreserved=perenniallyreserved,
                            )   



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def VirtualSerialPortOption(vim, *args, **kwargs):
    '''The data object contains the options for configuring the virtual serial port
    device defined by the data object. These options include information about how
    the device is backed physically on the host: by a network socket, a host file,
    a host serial port device, or a pipe to another process.'''

    obj = vim.client.factory.create('{urn:vim25}VirtualSerialPortOption')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 5:
        raise IndexError('Expected at least 6 arguments got: %d' % len(args))

    required = [ 'yieldOnPoll', 'deprecated', 'hotRemoveSupported', 'plugAndPlay', 'type' ]
    optional = [ 'autoAssignController', 'backingOption', 'connectOption', 'controllerType',
        'defaultBackingOptionIndex', 'licensingLimit', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostVirtualNicManagerNicType = Enum(
    'faultToleranceLogging',
    'management',
    'vmotion',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class EventManager(BaseEntity):
    '''This managed object type provides properties and methods for event management
    support. Event objects are used to record significant state changes of managed
    entities.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.EventManager):
        super(EventManager, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def description(self):
        '''Static descriptive strings used in events.'''
        return self.update('description')
    @property
    def latestEvent(self):
        '''The latest event that happened on the VirtualCenter server.'''
        return self.update('latestEvent')
    @property
    def maxCollector(self):
        '''For each client, the maximum number of event collectors that can exist
        simultaneously.'''
        return self.update('maxCollector')

    
    
    def CreateCollectorForEvents(self, filter):
        '''Creates an event history collector, which is a specialized history collector
        that provides Event objects.Creates an event history collector, which is a
        specialized history collector that provides Event objects.
        
        :param filter: The event query filter.
        
        '''
        return self.delegate("CreateCollectorForEvents")(filter)
    
    def LogUserEvent(self, entity, msg):
        '''Logs a user defined event against a particular managed entity.
        
        :param entity: The entity against which the event is logged. The entity must be the root folder, a DataCenter, a VirtualMachine, a HostSystem, or a ComputeResource.
        
        :param msg: The message to be logged.
        
        '''
        return self.delegate("LogUserEvent")(entity, msg)
    
    def PostEvent(self, eventToPost, taskInfo=None):
        '''Posts the specified event, optionally associating it with a task.Posts the
        specified event, optionally associating it with a task.Posts the specified
        event, optionally associating it with a task.Posts the specified event,
        optionally associating it with a task.
        
        :param eventToPost: Fully-specified event to post
        
        :param taskInfo: optional task associated with the event
        
        '''
        return self.delegate("PostEvent")(eventToPost, taskInfo)
    
    def QueryEvents(self, filter):
        '''Returns the events in specified filter. Returns empty array when there are not
        any events qualified.
        
        :param filter: The events qualified.
        
        '''
        return self.delegate("QueryEvents")(filter)
    
    def RetrieveArgumentDescription(self, eventTypeId):
        '''Retrieves the argument meta-data for a given Event type
        
        :param eventTypeId: 
        
        '''
        return self.delegate("RetrieveArgumentDescription")(eventTypeId)



from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class GuestOperationsManager(BaseEntity):
    '''GuestOperationsManager is the managed object that provides APIs to manipulate
    the guest operating system files and process. Each class of APIs is separated
    into its own manager.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.GuestOperationsManager):
        super(GuestOperationsManager, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def authManager(self):
        '''A singleton managed object that provides methods for guest authentication
        operations.'''
        return self.update('authManager')
    @property
    def fileManager(self):
        '''A singleton managed object that provides methods for guest file operations.'''
        return self.update('fileManager')
    @property
    def processManager(self):
        '''A singleton managed object that provides methods for guest process operations.'''
        return self.update('processManager')

    



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineAppHeartbeatStatusType = Enum(
    'appStatusGray',
    'appStatusGreen',
    'appStatusRed',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualSCSISharing = Enum(
    'noSharing',
    'physicalSharing',
    'virtualSharing',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

StoragePlacementSpecPlacementType = Enum(
    'clone',
    'create',
    'reconfigure',
    'relocate',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostDistributedVirtualSwitchManagerNetworkResourcePoolKey = Enum(
    'faultTolerance',
    'iSCSI',
    'management',
    'nfs',
    'virtualMachine',
    'vmotion',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualPointingDeviceHostChoice = Enum(
    'autodetect',
    'intellimouseExplorer',
    'intellimousePs2',
    'logitechMouseman',
    'microsoft_serial',
    'mousemanSerial',
    'mouseSystems',
    'ps2',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def EVCAdmissionFailedVmActive(vim, *args, **kwargs):
    '''An attempt to move or add a host into an Enhanced VMotion Compatibility cluster
    has failed for the following reason:Therefore the host may not be admitted into
    the cluster, since its virtual machines may be using CPU features suppressed in
    the cluster.Note that in rare cases, this may occur even if the host's
    maxEVCModeKey corresponds to the EVC mode of the cluster. This means that even
    though that EVC mode is the best match for the host's hardware, the host still
    has some features beyond those present in the baseline for that EVC mode.'''

    obj = vim.client.factory.create('{urn:vim25}EVCAdmissionFailedVmActive')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 6:
        raise IndexError('Expected at least 7 arguments got: %d' % len(args))

    required = [ 'productName', 'productVersion', 'dynamicProperty', 'dynamicType',
        'faultCause', 'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualDiskCompatibilityMode = Enum(
    'physicalMode',
    'virtualMode',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostCapability(vim, *args, **kwargs):
    '''Specifies the capabilities of the particular host. This set of capabilities is
    referenced in other parts of the API specification to indicate under what
    circumstances an API will throw a NotSupported fault.'''

    obj = vim.client.factory.create('{urn:vim25}HostCapability')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 37:
        raise IndexError('Expected at least 38 arguments got: %d' % len(args))

    required = [ 'backgroundSnapshotsSupported', 'cloneFromSnapshotSupported',
        'cpuMemoryResourceConfigurationSupported', 'datastorePrincipalSupported',
        'deltaDiskBackingsSupported', 'ftSupported', 'highGuestMemSupported',
        'iscsiSupported', 'localSwapDatastoreSupported', 'maintenanceModeSupported',
        'nfsSupported', 'nicTeamingSupported', 'perVMNetworkTrafficShapingSupported',
        'perVmSwapFiles', 'preAssignedPCIUnitNumbersSupported', 'rebootSupported',
        'recordReplaySupported', 'recursiveResourcePoolsSupported',
        'restrictedSnapshotRelocateSupported', 'sanSupported',
        'scaledScreenshotSupported', 'screenshotSupported', 'shutdownSupported',
        'snapshotRelayoutSupported', 'standbySupported', 'storageIORMSupported',
        'storageVMotionSupported', 'suspendedRelocateSupported', 'tpmSupported',
        'unsharedSwapVMotionSupported', 'virtualExecUsageSupported',
        'vlanTaggingSupported', 'vmDirectPathGen2Supported',
        'vmfsDatastoreMountCapable', 'vmotionSupported',
        'vmotionWithStorageVMotionSupported', 'vStorageCapable' ]
    optional = [ 'firewallIpRulesSupported', 'ftCompatibilityIssues', 'ipmiSupported',
        'loginBySSLThumbprintSupported', 'maxHostRunningVms', 'maxHostSupportedVcpus',
        'maxRunningVMs', 'maxSupportedVcpus', 'maxSupportedVMs',
        'replayCompatibilityIssues', 'replayUnsupportedReason',
        'servicePackageInfoSupported', 'supportedCpuFeature',
        'supportedVmfsMajorVersion', 'vmDirectPathGen2UnsupportedReason',
        'vmDirectPathGen2UnsupportedReasonExtended', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class View(BaseEntity):
    '''View is the base class for session-specific view objects. A view is a mechanism
    that supports selection of objects on the server and subsequently, access to
    those objects. To create a view, use the ViewManager methods. A view exists
    until you terminate it by calling the DestroyView method, or until the end of
    the session. Access to a view is limited to the session in which it is
    created.There are three types of views:* ContainerView * ListView *
    InventoryViewA view maintains a view list that contains managed object
    references. You can use a view with the PropertyCollector to retrieve data and
    obtain notification of changes to the virtual environment. For information
    about using views with the PropertyCollector, see the description of
    ViewManager.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.View):
        super(View, self).__init__(core, name=name, ref=ref, type=type)

    

    
    
    def DestroyView(self):
        '''Destroy this view.
        
        '''
        return self.delegate("DestroyView")()



from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class NetworkVswitchStandardPortgroupPolicyFailover(Base):
    '''
    Commands to manipulate failover policy setting for the given portgroup.
    '''
    moid = 'ha-cli-handler-network-vswitch-standard-portgroup-policy-failover'
    def set(self, portgroupname, activeuplinks=None, failback=None, failuredetection=None, loadbalancing=None, notifyswitches=None, standbyuplinks=None, usevswitch=None):
        '''
        Configure the Failover policy for a port group. These setting may potentially override virtual switch settings.
        :param activeuplinks: string, Configure the list of active adapters and their failover order. This list must be a comma seperated list of values with the uplink name and no spaces. Example:  --active-uplinks=vmnic0,vmnic3,vmnic7,vmnic1
        :param failback: boolean, Configure whether a NIC will be used immediately when it comes back in service after a failover
        :param failuredetection: string, Set the method of determining how a network outage is detected. 
    beacon: Detect failures based on active beaconing to the vswitch
    link: Detect failures based on the NIC link state

        :param loadbalancing: string, Set the load balancing policy for this policy. This can be one of the following options: 
    explicit: Always use the highest order uplink from the list of active adapters which pass failover criteria.
    iphash: Route based on hashing the src and destination IP addresses
    mac: Route based on the MAC address of the packet source.
    portid: Route based on the originating virtual port ID.

        :param notifyswitches: boolean, Indicate whether to send a notification to physical switches on failover
        :param portgroupname: string, The name of the port group to set failover policy for.
        :param standbyuplinks: string, Configure the list of standby adapters and their failover order. This list must be a comma seperated list of values with the uplink name and no spaces. Example:  --standby-uplinks=vmnic2,vmnic4,vmnic8,vmnic6,vmnic11
        :param usevswitch: boolean, Reset all values for this policy to use parent virtual switch's settings instead of overriding the settings for the port group. Using this in conjunction with other settings will first reset all of the fields to use the virtual switch setting and then apply the other options after the reset.
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.vswitch.standard.portgroup.policy.failover.Set',
                            activeuplinks=activeuplinks,
                            failback=failback,
                            failuredetection=failuredetection,
                            loadbalancing=loadbalancing,
                            notifyswitches=notifyswitches,
                            portgroupname=portgroupname,
                            standbyuplinks=standbyuplinks,
                            usevswitch=usevswitch,
                            )
    def get(self, portgroupname):
        '''
        Get the network failover policy settings governing the given port group
        :param portgroupname: string, The name of the port group to use when fetching the port group failover policy.
        :returns: vim.EsxCLI.network.vswitch.standard.portgroup.policy.failover.get.PortGroupFailoverPolicy
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.vswitch.standard.portgroup.policy.failover.Get',
                            portgroupname=portgroupname,
                            )   



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineConnectionState = Enum(
    'connected',
    'disconnected',
    'inaccessible',
    'invalid',
    'orphaned',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class HostHealthStatusSystem(BaseEntity):
    '''This managed object manages the health state of the host.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.HostHealthStatusSystem):
        super(HostHealthStatusSystem, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def runtime(self):
        ''''''
        return self.update('runtime')

    
    
    def RefreshHealthStatusSystem(self):
        '''Refresh the available runtime hardware health information.
        
        '''
        return self.delegate("RefreshHealthStatusSystem")()
    
    def ResetSystemHealthInfo(self):
        '''Resets the state of the sensors of the IPMI subsystem. On certain types of
        hardware IPMI sensor states latch onto unhealthy states and will stay in an
        unhealth state until the sensor state is reset. This method will explicitly
        reset the sensors state.
        
        '''
        return self.delegate("ResetSystemHealthInfo")()



from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.managed_object_view import ManagedObjectView

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class ContainerView(ManagedObjectView):
    '''The ContainerView managed object provides a means of monitoring the contents of
    a single container and, optionally, other containers. You can use a
    ContainerView with a PropertyCollector method to retrieve data or receive
    notification of changes. For information about using views with the
    PropertyCollector, see the description of ViewManager.When you invoke the
    CreateContainerView method, you specify a managed object instance that provides
    the starting point for object selection. You can use the following managed
    objects as the basis of a container view:* Folder * Datacenter *
    ComputeResource * ResourcePool * HostSystemOnce you have created the view, the
    view list always represents the current configuration of the virtual
    environment and reflects any subsequent changes that occur.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.ContainerView):
        super(ContainerView, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def container(self):
        '''The Folder, Datacenter, ComputeResource, ResourcePool, or HostSystem instance
        that provides the objects that the view presents.'''
        return self.update('container')
    @property
    def recursive(self):
        '''Whether to include only the immediate children of the container instance, or to
        include additional objects by following the paths beyond the immediate
        children.'''
        return self.update('recursive')
    @property
    def type(self):
        '''An optional list of types to be applied to the set of objects in the view. The
        list of types indicates objects that are included in the view. If empty, all
        types are included.'''
        return self.update('type')

    



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostMemoryProfile(vim, *args, **kwargs):
    '''The HostMemoryProfile data object represents memory configuration for the host.
    This may not be valid all versions of the host.Use the policy list for access
    to configuration data for the host memory profile. Use the property list for
    access to subprofile configuration data, if any.'''

    obj = vim.client.factory.create('{urn:vim25}HostMemoryProfile')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'enabled' ]
    optional = [ 'policy', 'profileTypeName', 'profileVersion', 'property', 'dynamicProperty',
        'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DistributedVirtualSwitchNicTeamingPolicyMode = Enum(
    'failover_explicit',
    'loadbalance_ip',
    'loadbalance_loadbased',
    'loadbalance_srcid',
    'loadbalance_srcmac',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class CustomFieldsManager(BaseEntity):
    '''The CustomFieldsManager object is used to add and remove custom fields to
    managed entities.The custom fields values set on managed entities are available
    through the customValue property and through the summary objects for
    VirtualMachine and HostSystem. They are not available directly through this
    managed object.This functionality is only available through VirtualCenter.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.CustomFieldsManager):
        super(CustomFieldsManager, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def field(self):
        '''List of custom fields defined on this server. The fields are sorted by name.'''
        return self.update('field')

    
    
    def AddCustomFieldDef(self, name, moType=None, fieldDefPolicy=None, fieldPolicy=None):
        '''Creates a new custom field. If the moType is specified, the field will only be
        available for that type of managed object.
        
        :param name: The name of the field.
        
        :param moType: The managed object type to which this field will applyVI API 2.5
        
        :param fieldDefPolicy: Privilege policy to apply to FieldDef being createdVI API 2.5
        
        :param fieldPolicy: Privilege policy to apply to instances of fieldVI API 2.5
        
        '''
        return self.delegate("AddCustomFieldDef")(name, moType, fieldDefPolicy, fieldPolicy)
    
    def RemoveCustomFieldDef(self, key):
        '''Removes a custom field. This also removes all values assigned to this custom
        field.
        
        :param key: The unique key for the field definition.
        
        '''
        return self.delegate("RemoveCustomFieldDef")(key)
    
    def RenameCustomFieldDef(self, key, name):
        '''Renames a custom field.
        
        :param key: The unique key for the field definition.
        
        :param name: The new name for the field.
        
        '''
        return self.delegate("RenameCustomFieldDef")(key, name)
    
    def SetField(self, entity, key, value):
        '''Assigns a value to a custom field on an entity.
        
        :param entity: 
        
        :param key: 
        
        :param value: 
        
        '''
        return self.delegate("SetField")(entity, key, value)



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

NodeStatus = Enum(
    'degraded',
    'down',
    'notReported',
    'unknown',
    'up',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.extensible_managed_object import ExtensibleManagedObject

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class Task(ExtensibleManagedObject):
    '''A task is used to monitor and potentially cancel long running operations.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.Task):
        super(Task, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def info(self):
        '''Detailed information about this task.'''
        return self.update('info')

    
    
    def CancelTask(self):
        '''Cancels a running or queued task. A task may only be canceled if it is
        cancelable. Multiple cancel requests will be treated as a single cancelation
        request. Canceling a completed or already canceled task will throw an
        InvalidState exception.Cancels a running or queued task. A task may only be
        canceled if it is cancelable. Multiple cancel requests will be treated as a
        single cancelation request. Canceling a completed or already canceled task will
        throw an InvalidState exception.Cancels a running or queued task. A task may
        only be canceled if it is cancelable. Multiple cancel requests will be treated
        as a single cancelation request. Canceling a completed or already canceled task
        will throw an InvalidState exception.
        
        '''
        return self.delegate("CancelTask")()
    
    def SetTaskDescription(self, description):
        '''Updates task description to describe the current phase of the task.
        
        :param description: New description for task
        
        '''
        return self.delegate("SetTaskDescription")(description)
    
    def SetTaskState(self, state, result=None, fault=None):
        '''Sets task state and optionally sets results or fault, as appropriate for state
        
        :param state: New state for task
        
        :param result: Result to set, valid only if task state is TaskInfo.State.success
        
        :param fault: Fault to set, valid only if task state is error. The fault must be a of a fault type that directly or indirectly extends VimFault.
        
        '''
        return self.delegate("SetTaskState")(state, result, fault)
    
    def UpdateProgress(self, percentDone):
        '''Sets percentage done for this task and recalculates overall percentage done. If
        a percentDone value of less than zero or greater than 100 is specified, a value
        of zero or 100 respectively is used.
        
        :param percentDone: Percentage to set for this task
        
        '''
        return self.delegate("UpdateProgress")(percentDone)



from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.extensible_managed_object import ExtensibleManagedObject

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class VirtualMachineSnapshot(ExtensibleManagedObject):
    '''The Snapshot managed object type specifies the interface to individual
    snapshots of a virtual machine. Although these are managed objects, they are
    subordinate to their virtual machine.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.VirtualMachineSnapshot):
        super(VirtualMachineSnapshot, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def childSnapshot(self):
        '''All snapshots for which this snapshot is the parent.'''
        return self.update('childSnapshot')
    @property
    def config(self):
        '''Information about the configuration of this virtual machine when this snapshot
        was taken.'''
        return self.update('config')

    
    
    def RemoveSnapshot_Task(self, removeChildren, consolidate=None):
        '''Removes this snapshot and deletes any associated storage.
        
        :param removeChildren: Flag to specify removal of the entire snapshot subtree.
        
        :param consolidate: (optional) If set to true, the virtual disk associated with this snapshot will be merged with other disk if possible. Defaults to true.vSphere API 5.0
        
        '''
        return self.delegate("RemoveSnapshot_Task")(removeChildren, consolidate)
    
    def RenameSnapshot(self, name=None, description=None):
        '''Rename this snapshot with either a new name or a new description or both. At
        least one of these must be specified when calling the rename method.
        
        :param name: New name for the snapshot.
        
        :param description: New description for the snapshot.
        
        '''
        return self.delegate("RenameSnapshot")(name, description)
    
    def RevertToSnapshot_Task(self, host=None, suppressPowerOn=None):
        '''Change the execution state of the virtual machine to the state of this
        snapshot.
        
        :param host: (optional) Choice of host for the virtual machine, in case this operation causes the virtual machine to power on.
        
        :param suppressPowerOn: (optional) If set to true, the virtual machine will not be powered on regardless of the power state when the snapshot was created. Default to false.vSphere API 4.0
        
        '''
        return self.delegate("RevertToSnapshot_Task")(host, suppressPowerOn)



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def QueryResult(vim, *args, **kwargs):
    '''Comprises the result set of a specific QueryList operation. This data object
    contains metadata and row data. The Metadata object contains information about
    the number of rows in the result set and the column names in the result set.
    Use the propertyName strings to deocde the RowData objects in the result set.
    See for more information and for tables of entity and relationship properties.'''

    obj = vim.client.factory.create('{urn:sms}QueryResult')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'metadata' ]
    optional = [ 'row', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class PerformanceManager(BaseEntity):
    '''This managed object type provides the service interface for obtaining
    statistical data about various aspects of system performance, as generated and
    maintained by the system's performance providers. A "performance provider"
    (PerfProviderSummary) is any managed object that generates utilization or other
    performance metrics. Performance providers include managed entities, such as
    hosts, virtual machines, compute resources, resource pools, datastores, and
    networks. Performance providers also include physical or virtual devices
    associated with these objects, such as virtual host-bus adapters and network-
    interface controllers (NICs)Each performance providerthe instrumented device
    or entityhas its own set of counters that provides metadata about its
    available metrics. Each counter has a unique key, referred to as the counterId.
    The actual performance metrics generated at runtime are identified by this
    counterId. Counters are organized by groups of finite system resources, such as
    , , , and so on. The links in this list contain documentation for performance
    counters, by group. Each page contains a table that includes data extracted
    from instances of the PerfCounterInfo data object, including the counter name,
    its Label, Unit, StatsType, RollupType, and Level:* * * * * * * * * Storage
    Capacity: * * Storage I/O: * * * * * * * *Other performance-counter groups, in
    addition to those listed here, exist on the system. However, only the counter
    groups listed are considered of possible interest to third-party
    developers.This interface provides these query operations:*
    QueryPerfProviderSummary, for obtaining metatdata about performance providers *
    QueryPerfCounter and QueryPerfCounterByLevel for obtaining metadata about
    supported counters. * QueryPerf, QueryAvailablePerfMetric, and
    QueryPerfComposite for obtaining statistics for one or more entities: * Use
    QueryPerf to obtain metrics for multiple entities in a single call. * Use
    QueryPerfComposite to obtain statistics for a single entity with its descendent
    objectsstatistics for a host and all its virtual machines, for example.Some
    differences between ESX and vCenter Server implementations of this interface
    include:* For ESX systems, this interface provides access to real-time data,
    and to real-time data that has been rolled up into "PastDay" statistics (if
    applicable for the specific counter). * For vCenter Server systems, this
    interface provides access to real-time and historical data. vCenter Server
    collects statistics on a regular basis from all ESX systems that it manages,
    and aggregates the results based on the level settings for the server. *
    Default sampling interval is product- and version-specific: * ESX 3.x (and
    subsequent) systems: 20 second interval * ESX 2.x systems: 60 second interval *
    VirtualCenter Server 2.5 (and subsequent vCenter Server) systems initially
    collect statistics data 10 minutes after system startup, and then hourly
    thereafter.See the Programming Guide for more information about using
    PerformanceManager.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.PerformanceManager):
        super(PerformanceManager, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def description(self):
        '''The static description strings.'''
        return self.update('description')
    @property
    def historicalInterval(self):
        '''A list of intervals configured on the system.'''
        return self.update('historicalInterval')
    @property
    def perfCounter(self):
        '''A list of all supported performance counters in the system.'''
        return self.update('perfCounter')

    
    
    def CreatePerfInterval(self, intervalId):
        '''<b>Deprecated.</b> <i>As of API 2.5, use UpdatePerfInterval. The default
        historical intervals can be modified, but they cannot be created.</i> Adds a
        new historical interval. Sampling period for new interval must be a multiple of
        an existing interval; must comprise a longer period of time; and must be
        uniquely named.
        
        :param intervalId: A custom interval, specified as the number of seconds to hold data in the database, a user-specified unique name, and a sampling period (in seconds).
        
        '''
        return self.delegate("CreatePerfInterval")(intervalId)
    
    def QueryAvailablePerfMetric(self, entity, beginTime=None, endTime=None, intervalId=None):
        '''Retrieves all performance counters for the specified managed object generated
        during a specified period of time. The time period can be specified using
        beginTime, endTime, or by interval ID.
        
        :param entity: The managed object that provides performance metrics.
        
        :param beginTime: Starting time (server time) for a period of time from which to return available metrics. If not specified, defaults to oldest available metric for the specified entity.
        
        :param endTime: Ending time (server time) for a period of time from which to return available performance metrics. If not specified, defaults to the most recently generated metric for the specified entity.
        
        :param intervalId: Period of time from which to retrieve metrics, defined by intervalId (rather than beginTime or endTime). Valid intervalIds include: * For real-time counters, the refreshRate of the performance provider. * For historical counters, the historical interval. If this parameter is not specified, the system returns available metrics for historical statistics.
        
        '''
        return self.delegate("QueryAvailablePerfMetric")(entity, beginTime, endTime, intervalId)
    
    def QueryPerf(self, querySpec):
        '''Retrieves the performance metrics for the specified entity (or entities) based
        on the properties specified in the PerfQuerySpec data object.Retrieves the
        performance metrics for the specified entity (or entities) based on the
        properties specified in the PerfQuerySpec data object.
        
        :param querySpec: An array of PerfQuerySpec objects. Each PerfQuerySpec object specifies a managed object reference for an entity, plus optional criteria for filtering results. Only metrics for entities that can be resolved and that are valid performance providers are returned in any result.
        
        '''
        return self.delegate("QueryPerf")(querySpec)
    
    def QueryPerfComposite(self, querySpec):
        '''Retrieves a PerfCompositeMetric data object that comprises statistics for the
        specified entity and its children entities. Only metrics for the first level of
        descendents are included in the PerfCompositeMetric object.Retrieves a
        PerfCompositeMetric data object that comprises statistics for the specified
        entity and its children entities. Only metrics for the first level of
        descendents are included in the PerfCompositeMetric object.Retrieves a
        PerfCompositeMetric data object that comprises statistics for the specified
        entity and its children entities. Only metrics for the first level of
        descendents are included in the PerfCompositeMetric object.
        
        :param querySpec: A PerfQuerySpec object specifying the query parameters. This PerfQuerySpec object specifies a managed object for which composite statistics should be retrieved, with specific optional criteria for filtering the results.
        
        '''
        return self.delegate("QueryPerfComposite")(querySpec)
    
    def QueryPerfCounter(self, counterId):
        '''Retrieves counter information for the specified list of counter IDs.
        
        :param counterId: An array of one or more counterIds representing performance counters for which information is being retrieved.
        
        '''
        return self.delegate("QueryPerfCounter")(counterId)
    
    def QueryPerfCounterByLevel(self, level):
        '''Retrieves the set of counters that are available at a specified collection
        level. The collection level determines the statistics that get stored in
        VirtualCenter. See PerfInterval for more information about VirtualCenter Server
        historical statistics collection.
        
        :param level: A number between 1 and 4 that specifies the collection level.
        
        '''
        return self.delegate("QueryPerfCounterByLevel")(level)
    
    def QueryPerfProviderSummary(self, entity):
        '''Retrieves the PerfProviderSummary data object that defines the capabilities of
        the specified managed object with respect to statistics, such as whether it
        supports current or summary statistics.
        
        :param entity: Reference to a managed object that provides performance data. If the entity specified by managed object reference is not a performance provider, an "InvalidArgument" exception is thrown.
        
        '''
        return self.delegate("QueryPerfProviderSummary")(entity)
    
    def RemovePerfInterval(self, samplePeriod):
        '''<b>Deprecated.</b> <i>As of API 2.5, use UpdatePerfInterval. Historical
        intervals cannot be removed.</i> Removes an interval from the list.
        
        :param samplePeriod: The sampling period, in seconds, for the specified interval being removed.
        
        '''
        return self.delegate("RemovePerfInterval")(samplePeriod)
    
    def ResetCounterLevelMapping(self, counters):
        '''Restores a set of performance counters to the default level of data collection.
        See the <a href="#counterTables">performance counter tables</a> for the default
        collection level for individual counters.
        
        :param counters: An array of counter ids.
        
        '''
        return self.delegate("ResetCounterLevelMapping")(counters)
    
    def UpdateCounterLevelMapping(self, counterLevelMap):
        '''Changes the level of data collection for a set of performance counters. See the
        <a href="#counterTables">performance counter tables</a> for the default
        collection level for individual counters.
        
        :param counterLevelMap: An array of PerformanceManagerCounterLevelMapping objects. The levels for the counters passed in are changed to the passed in values. If the optional aggregateLevel field is left unset then only the perDeviceLevel is configured. If the optional perDeviceLevel is left unset then only the aggregateLevel is configured. If there are multiple entries in the passed in array for the same counterId being updated then the last entry containing the counterId takes effect.
        
        '''
        return self.delegate("UpdateCounterLevelMapping")(counterLevelMap)
    
    def UpdatePerfInterval(self, interval):
        '''Modifies VirtualCenter Server's built-in historical intervals, within certain
        limits.Modifies VirtualCenter Server's built-in historical intervals, within
        certain limits.
        
        :param interval: The historical interval being modified, a complete data object comprising values for enabled, interval ID, length of time to maintain statistics for this interval in the database, level, name, and samplingPeriod properties.
        
        '''
        return self.delegate("UpdatePerfInterval")(interval)



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostDnsConfig(vim, *args, **kwargs):
    '''This data object type describes the DNS configuration.All IPv4 addresses,
    subnet addresses, and netmasks are specified using dotted decimal notation. For
    example, "192.0.2.1". IPv6 addresses are 128-bit addresses represented as eight
    fields of up to four hexadecimal digits. A colon separates each field (:). For
    example, 2001:DB8:101::230:6eff:fe04:d9ff. The address can also consist of the
    symbol '::' to represent multiple 16-bit groups of contiguous 0's only once in
    an address as described in RFC 2373.'''

    obj = vim.client.factory.create('{urn:vim25}HostDnsConfig')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 3:
        raise IndexError('Expected at least 4 arguments got: %d' % len(args))

    required = [ 'dhcp', 'domainName', 'hostName' ]
    optional = [ 'address', 'searchDomain', 'virtualNicDevice', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostStandbyMode = Enum(
    'entering',
    'exiting',
    'in',
    'none',

)




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class StorageNmpSatpGenericPathconfig(Base):
    '''
    SATP path configuration operations
    '''
    moid = 'ha-cli-handler-storage-nmp-satp-generic-pathconfig'
    def set(self, config, path):
        '''
        Allow setting of per path SATP configuration parameters.  This command will set the configuration for the given path with whichever SATP it is currently configurated with.
        :param config: string, The configuration string you wish to set.
        :param path: string, The path you wish to set SATP configuration for.
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.nmp.satp.generic.pathconfig.Set',
                            config=config,
                            path=path,
                            )
    def get(self, path):
        '''
        Allow retrieving of per path SATP configuration parameters.
        :param path: string, The path you wish to get SATP configuration for.
        :returns: string
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.nmp.satp.generic.pathconfig.Get',
                            path=path,
                            )   



from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.extensible_managed_object import ExtensibleManagedObject

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class HostPciPassthruSystem(ExtensibleManagedObject):
    '''This managed object manages the PciPassthru state of the host.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.HostPciPassthruSystem):
        super(HostPciPassthruSystem, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def pciPassthruInfo(self):
        '''Array of PciPassthru information'''
        return self.update('pciPassthruInfo')

    
    
    def Refresh(self):
        '''Refresh the available PciPassthru information.
        
        '''
        return self.delegate("Refresh")()
    
    def UpdatePassthruConfig(self, config):
        '''Updates the PciPassthru configuration, this will get called for the dependent
        device with the enabled bool set
        
        :param config: The new PciPassthru configuration information.
        
        '''
        return self.delegate("UpdatePassthruConfig")(config)



from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class SystemModuleParameters(Base):
    '''
    Operations that allow manipulation of parameters of VMkernel loadable modules and device drivers. Operations include list and set options.
    '''
    moid = 'ha-cli-handler-system-module-parameters'
    def set(self, module, parameterstring, force=None):
        '''
        Set the load time parameters for the given VMkernel module.
        :param force: boolean, Skip VMkernel module validity checks and set parameters for a module (or alias) with the given name.
        :param module: string, The name of the VMkernel module to set parameters for.
        :param parameterstring: string, The string containing the parameters for this module.
        :returns: void
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.system.module.parameters.Set',
                            force=force,
                            module=module,
                            parameterstring=parameterstring,
                            )
    def list(self, module):
        '''
        List the parameters, a descriptions of each parameter supported for a given module name and the user defined value for each parameter.
        :param module: string, The name of the VMkernel module to get the option string for.
        :returns: vim.EsxCLI.system.module.parameters.list.ModuleParameter[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.system.module.parameters.List',
                            module=module,
                            )   



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostForceMountedInfo(vim, *args, **kwargs):
    '''When the system detects a copy of a VmfsVolume, it will not be auto-mounted on
    the host and it will be detected as 'UnresolvedVmfsVolume'. If user decides to
    keep the original Uuid and mount it on the host, it will have 'forceMounted'
    flag and 'forceMountedInfo' set. 'ForceMountedInfo' provides additional
    information specific to user-mounted VmfsVolume.'''

    obj = vim.client.factory.create('{urn:vim25}HostForceMountedInfo')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 2:
        raise IndexError('Expected at least 3 arguments got: %d' % len(args))

    required = [ 'mounted', 'persist' ]
    optional = [ 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.profile_manager import ProfileManager

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class ClusterProfileManager(ProfileManager):
    ''''''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.ClusterProfileManager):
        super(ClusterProfileManager, self).__init__(core, name=name, ref=ref, type=type)

    

    



from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class EsxcliCommand(Base):
    '''
    Operations to get information about commands.
    '''
    moid = 'ha-cli-handler-esxcli-command'
    def list(self):
        '''
        This command will list all of the esxcli commands with their namespace, object, command name and description.
        :returns: vim.EsxCLI.esxcli.command.list.EsxCliCommand[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.esxcli.command.List',
                            )   



from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.managed_entity import ManagedEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class HostSystem(ManagedEntity):
    '''The HostSystem managed object type provides access to a virtualization host
    platform.Invoking destroy on a HostSystem of standalone type throws a
    NotSupported fault. A standalone HostSystem can be destroyed only by invoking
    destroy on its parent ComputeResource. Invoking destroy on a failover host
    throws a DisallowedOperationOnFailoverHost fault. See
    ClusterFailoverHostAdmissionControlPolicy.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.HostSystem):
        super(HostSystem, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def capability(self):
        '''Host capabilities. This might not be available for a disconnected host.'''
        return self.update('capability')
    @property
    def config(self):
        '''Host configuration information. This might not be available for a disconnected
        host.'''
        return self.update('config')
    @property
    def configManager(self):
        '''Host configuration systems.'''
        return self.update('configManager')
    @property
    def datastore(self):
        '''A collection of references to the subset of datastore objects in the datacenter
        that are available in this HostSystem.'''
        return self.update('datastore')
    @property
    def datastoreBrowser(self):
        '''DatastoreBrowser to browse datastores for this host.'''
        return self.update('datastoreBrowser')
    @property
    def hardware(self):
        '''Hardware configuration of the host. This might not be available for a
        disconnected host.'''
        return self.update('hardware')
    @property
    def licensableResource(self):
        '''Information about all licensable resources, currently present on this host.'''
        return self.update('licensableResource')
    @property
    def network(self):
        '''A collection of references to the subset of network objects in the datacenter
        that are available in this HostSystem.'''
        return self.update('network')
    @property
    def runtime(self):
        '''Runtime state information about the host such as connection state.'''
        return self.update('runtime')
    @property
    def summary(self):
        '''Basic information about the host, including connection state.'''
        return self.update('summary')
    @property
    def systemResources(self):
        '''Reference for the system resource hierarchy, used for configuring the set of
        resources reserved to the system and unavailable to virtual machines.'''
        return self.update('systemResources')
    @property
    def vm(self):
        '''List of virtual machines associated with this host.'''
        return self.update('vm')

    
    
    def AcquireCimServicesTicket(self):
        '''Creates and returns a one-time credential used to establish a remote connection
        to a CIM interface. The port to connect to is the standard well known port for
        the service.
        
        '''
        return self.delegate("AcquireCimServicesTicket")()
    
    def DisconnectHost_Task(self):
        '''Disconnects from a host and instructs the server to stop sending heartbeats.
        
        '''
        return self.delegate("DisconnectHost_Task")()
    
    def EnterLockdownMode(self):
        '''Modifies the permissions on the host, so that it will only be accessible
        through local console or an authorized centralized management application. Any
        user defined permissions found on the host are lost.Modifies the permissions on
        the host, so that it will only be accessible through local console or an
        authorized centralized management application. Any user defined permissions
        found on the host are lost.Modifies the permissions on the host, so that it
        will only be accessible through local console or an authorized centralized
        management application. Any user defined permissions found on the host are
        lost.
        
        '''
        return self.delegate("EnterLockdownMode")()
    
    def EnterMaintenanceMode_Task(self, timeout, evacuatePoweredOffVms=None):
        '''Puts the host in maintenance mode. While this task is running and when the host
        is in maintenance mode, no virtual machines can be powered on and no
        provisioning operations can be performed on the host. Once the call completes,
        it is safe to turn off a host without disrupting any virtual machines.Puts the
        host in maintenance mode. While this task is running and when the host is in
        maintenance mode, no virtual machines can be powered on and no provisioning
        operations can be performed on the host. Once the call completes, it is safe to
        turn off a host without disrupting any virtual machines.Puts the host in
        maintenance mode. While this task is running and when the host is in
        maintenance mode, no virtual machines can be powered on and no provisioning
        operations can be performed on the host. Once the call completes, it is safe to
        turn off a host without disrupting any virtual machines.
        
        :param timeout: The task completes when the host successfully enters maintenance mode or the timeout expires, and in the latter case the task contains a Timeout fault. If the timeout is less than or equal to zero, there is no timeout. The timeout is specified in seconds.
        
        :param evacuatePoweredOffVms: This is a parameter only supported by VirtualCenter. If set to true, for a DRS disabled cluster, the task will not succeed unless all powered-off virtual machines have been manually reregistered; for a DRS enabled cluster, VirtualCenter will automatically reregister powered-off virtual machines and a powered-off virtual machine may remain at the host only for two reasons: (a) no compatible host found for reregistration, (b) DRS is disabled for the virtual machine. If set to false, powered-off virtual machines do not need to be moved.VI API 2.5
        
        '''
        return self.delegate("EnterMaintenanceMode_Task")(timeout, evacuatePoweredOffVms)
    
    def ExitLockdownMode(self):
        '''Restores Administrator permission for the local administrative account for the
        host that was removed by prior call to EnterLockdownMode. If the operation is
        successful, adminDisabled will be set to false. This API is not supported on
        the host. If invoked directly on a host, a NotSupported fault will be
        thrown.See AuthorizationManager
        
        '''
        return self.delegate("ExitLockdownMode")()
    
    def ExitMaintenanceMode_Task(self, timeout):
        '''Takes the host out of maintenance mode. This blocks if any concurrent running
        maintenance-only host configurations operations are being performed. For
        example, if VMFS volumes are being upgraded.Takes the host out of maintenance
        mode. This blocks if any concurrent running maintenance-only host
        configurations operations are being performed. For example, if VMFS volumes are
        being upgraded.
        
        :param timeout: Number of seconds to wait for the exit maintenance mode to succeed. If the timeout is less than or equal to zero, there is no timeout.
        
        '''
        return self.delegate("ExitMaintenanceMode_Task")(timeout)
    
    def PowerDownHostToStandBy_Task(self, timeoutSec, evacuatePoweredOffVms=None):
        '''Puts the host in standby mode, a mode in which the host is in a standby state
        from which it can be powered up remotely. While this task is running, no
        virtual machines can be powered on and no provisioning operations can be
        performed on the host.Puts the host in standby mode, a mode in which the host
        is in a standby state from which it can be powered up remotely. While this task
        is running, no virtual machines can be powered on and no provisioning
        operations can be performed on the host.Puts the host in standby mode, a mode
        in which the host is in a standby state from which it can be powered up
        remotely. While this task is running, no virtual machines can be powered on and
        no provisioning operations can be performed on the host.Puts the host in
        standby mode, a mode in which the host is in a standby state from which it can
        be powered up remotely. While this task is running, no virtual machines can be
        powered on and no provisioning operations can be performed on the host.
        
        :param timeoutSec: The task completes when the host successfully enters standby mode and stops sending heartbeat signals. If heartbeats are still coming after timeoutSecs seconds, the host is declared timedout, and the task is assumed failed.
        
        :param evacuatePoweredOffVms: This is a parameter used only by VirtualCenter. If set to true, for a DRS disabled cluster, the task will not succeed unless all powered-off virtual machines have been manually reregistered; for a DRS enabled cluster, VirtualCenter will automatically reregister powered-off virtual machines and a powered-off virtual machine may remain at the host only for two reasons: (a) no compatible host found for reregistration, (b) DRS is disabled for the virtual machine.
        
        '''
        return self.delegate("PowerDownHostToStandBy_Task")(timeoutSec, evacuatePoweredOffVms)
    
    def PowerUpHostFromStandBy_Task(self, timeoutSec):
        '''Takes the host out of standby mode. If the command is successful, the host
        wakes up and starts sending heartbeats. This method may be called automatically
        by a dynamic recommendation generation module to add capacity to a cluster, if
        the host is not in maintenance mode.Takes the host out of standby mode. If the
        command is successful, the host wakes up and starts sending heartbeats. This
        method may be called automatically by a dynamic recommendation generation
        module to add capacity to a cluster, if the host is not in maintenance
        mode.Takes the host out of standby mode. If the command is successful, the host
        wakes up and starts sending heartbeats. This method may be called automatically
        by a dynamic recommendation generation module to add capacity to a cluster, if
        the host is not in maintenance mode.
        
        :param timeoutSec: The task completes when the host successfully exits standby state and sends a heartbeat signal. If nothing is received from the host for timeoutSec seconds, the host is declared timedout, and the task is assumed failed.
        
        '''
        return self.delegate("PowerUpHostFromStandBy_Task")(timeoutSec)
    
    def QueryHostConnectionInfo(self):
        '''Connection-oriented information about a host.
        
        '''
        return self.delegate("QueryHostConnectionInfo")()
    
    def QueryMemoryOverhead(self, memorySize, numVcpus, videoRamSize=None):
        '''<b>Deprecated.</b> <i>As of VI API 2.5, use QueryMemoryOverheadEx.</i>
        Determines the amount of memory overhead necessary to power on a virtual
        machine with the specified characteristics.
        
        :param memorySize: The amount of virtual system RAM, in bytes. For an existing virtual machine, this value can be found (in megabytes) as the memoryMB property of the VirtualHardware.
        
        :param videoRamSize: The amount of virtual video RAM, in bytes. For an existing virtual machine on a host that supports advertising this property, this value can be found (in kilobytes) as the videoRamSizeInKB property of the VirtualMachineVideoCard. If this parameter is left unset, the default video RAM size for virtual machines on this host is assumed.
        
        :param numVcpus: The number of virtual CPUs. For an existing virtual machine, this value can be found as the numCPU property of the VirtualHardware.
        
        '''
        return self.delegate("QueryMemoryOverhead")(memorySize, videoRamSize, numVcpus)
    
    def QueryMemoryOverheadEx(self, vmConfigInfo):
        '''Determines the amount of memory overhead necessary to power on a virtual
        machine with the specified characteristics.
        
        :param vmConfigInfo: The configuration of the virtual machine.
        
        '''
        return self.delegate("QueryMemoryOverheadEx")(vmConfigInfo)
    
    def RebootHost_Task(self, force):
        '''Reboots a host. If the command is successful, then the host has been rebooted.
        If connected directly to the host, the client never receives an indicator of
        success in the returned task but simply loses connection to the host, upon
        success.Reboots a host. If the command is successful, then the host has been
        rebooted. If connected directly to the host, the client never receives an
        indicator of success in the returned task but simply loses connection to the
        host, upon success.
        
        :param force: Flag to specify whether or not the host should be rebooted regardless of whether it is in maintenance mode. If true, the host is rebooted, even if there are virtual machines running or other operations in progress.
        
        '''
        return self.delegate("RebootHost_Task")(force)
    
    def ReconfigureHostForDAS_Task(self):
        '''Reconfigures the host for vSphere HA.Reconfigures the host for vSphere HA.
        
        '''
        return self.delegate("ReconfigureHostForDAS_Task")()
    
    def ReconnectHost_Task(self, cnxSpec=None, reconnectSpec=None):
        '''Reconnects to a host. This process reinstalls agents and reconfigures the host,
        if it has gotten out of date with VirtualCenter. The reconnection process goes
        through many of the same steps as addHost: ensuring the correct set of licenses
        for the number of CPUs on the host, ensuring the correct set of agents is
        installed, and ensuring that networks and datastores are discovered and
        registered with VirtualCenter.Reconnects to a host. This process reinstalls
        agents and reconfigures the host, if it has gotten out of date with
        VirtualCenter. The reconnection process goes through many of the same steps as
        addHost: ensuring the correct set of licenses for the number of CPUs on the
        host, ensuring the correct set of agents is installed, and ensuring that
        networks and datastores are discovered and registered with
        VirtualCenter.Reconnects to a host. This process reinstalls agents and
        reconfigures the host, if it has gotten out of date with VirtualCenter. The
        reconnection process goes through many of the same steps as addHost: ensuring
        the correct set of licenses for the number of CPUs on the host, ensuring the
        correct set of agents is installed, and ensuring that networks and datastores
        are discovered and registered with VirtualCenter.Reconnects to a host. This
        process reinstalls agents and reconfigures the host, if it has gotten out of
        date with VirtualCenter. The reconnection process goes through many of the same
        steps as addHost: ensuring the correct set of licenses for the number of CPUs
        on the host, ensuring the correct set of agents is installed, and ensuring that
        networks and datastores are discovered and registered with
        VirtualCenter.Reconnects to a host. This process reinstalls agents and
        reconfigures the host, if it has gotten out of date with VirtualCenter. The
        reconnection process goes through many of the same steps as addHost: ensuring
        the correct set of licenses for the number of CPUs on the host, ensuring the
        correct set of agents is installed, and ensuring that networks and datastores
        are discovered and registered with VirtualCenter.
        
        :param cnxSpec: Includes the parameters to use, including user name and password, when reconnecting to the host. If this parameter is not specified, the default connection parameters is used.
        
        :param reconnectSpec: Includes connection parameters specific to reconnect. This will mainly be used to indicate how to handle divergence between the host settings and vCenter Server settings when the host was disconnected.vSphere API 5.0
        
        '''
        return self.delegate("ReconnectHost_Task")(cnxSpec, reconnectSpec)
    
    def RetrieveHardwareUptime(self):
        '''Return the hardware uptime of the host in seconds. The harware uptime of a host
        is not affected by NTP and changes to its wall clock time and can be used by
        clients to provide a common time reference for all hosts.
        
        '''
        return self.delegate("RetrieveHardwareUptime")()
    
    def ShutdownHost_Task(self, force):
        '''Shuts down a host. If the command is successful, then the host has been shut
        down. Thus, the client never receives an indicator of success in the returned
        task if connected directly to the host.Shuts down a host. If the command is
        successful, then the host has been shut down. Thus, the client never receives
        an indicator of success in the returned task if connected directly to the host.
        
        :param force: Flag to specify whether or not the host should be shut down regardless of whether it is in maintenance mode. If true, the host is shut down, even if there are virtual machines running or other operations in progress.
        
        '''
        return self.delegate("ShutdownHost_Task")(force)
    
    def UpdateFlags(self, flagInfo):
        '''Update flags that are part of the HostFlagInfo object.
        
        :param flagInfo: 
        
        '''
        return self.delegate("UpdateFlags")(flagInfo)
    
    def UpdateIpmi(self, ipmiInfo):
        '''Update fields that are part of the HostIpmiInfo object.
        
        :param ipmiInfo: 
        
        '''
        return self.delegate("UpdateIpmi")(ipmiInfo)
    
    def UpdateSystemResources(self, resourceInfo):
        '''Update the configuration of the system resource hierarchy.
        
        :param resourceInfo: 
        
        '''
        return self.delegate("UpdateSystemResources")(resourceInfo)

    def RetrieveManagedMethodExecuter(self):
        return self.delegate("RetrieveManagedMethodExecuter")()
   
    def RetrieveDynamicTypeManager(self):
        return self.delegate("RetrieveDynamicTypeManager")()





########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineFileLayoutExFileType = Enum(
    'config',
    'core',
    'digestDescriptor',
    'digestExtent',
    'diskDescriptor',
    'diskExtent',
    'diskReplicationState',
    'extendedConfig',
    'log',
    'nvram',
    'screenshot',
    'snapshotData',
    'snapshotList',
    'snapshotManifestList',
    'stat',
    'suspend',
    'swap',
    'uwswap',

)




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class NetworkVswitchStandardPortgroupPolicyShaping(Base):
    '''
    Commands to manipulate shaping policy setting for the given portgroup.
    '''
    moid = 'ha-cli-handler-network-vswitch-standard-portgroup-policy-shaping'
    def set(self, portgroupname, avgbandwidth=None, burstsize=None, enabled=None, peakbandwidth=None, usevswitch=None):
        '''
        Set the shaping policy settings for the given port group
        :param avgbandwidth: long, The averge bandwidth allowed for this shaping policy. This value is in Kbps (1 Kbps = 1000 bits/s)
        :param burstsize: long, The largest burst size allowed for this shaping policy. This value is in Kib (1 Kib = 1024 bits)
        :param enabled: boolean, Indicate whether to enable traffic shaping on this policy. If this is true then the --avg-bandwidth, --peak-bandwidth and --burst-size options are required.
        :param peakbandwidth: long, The peak bandwidth allowed for this shaping policy. This value is in Kbps (1 Kbps = 1000 bits/s)
        :param portgroupname: string, The name of the port group to set shaping policy for.
        :param usevswitch: boolean, Reset all values for this policy to use parent virtual switch's settings instead of overriding the settings for the port group. Using this in conjunction with other settings will first reset all of the fields to use the virtual switch setting and then apply the other options after the reset.
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.vswitch.standard.portgroup.policy.shaping.Set',
                            avgbandwidth=avgbandwidth,
                            burstsize=burstsize,
                            enabled=enabled,
                            peakbandwidth=peakbandwidth,
                            portgroupname=portgroupname,
                            usevswitch=usevswitch,
                            )
    def get(self, portgroupname):
        '''
        Get the network shaping policy settings governing the given port group
        :param portgroupname: string, The name of the port group to use when fetching the port group shaping policy.
        :returns: vim.EsxCLI.network.vswitch.standard.portgroup.policy.shaping.get.PortGroupTrafficShapingPolicy
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.vswitch.standard.portgroup.policy.shaping.Get',
                            portgroupname=portgroupname,
                            )   



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineFaultToleranceState = Enum(
    'disabled',
    'enabled',
    'needSecondary',
    'notConfigured',
    'running',
    'starting',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineToolsStatus = Enum(
    'toolsNotInstalled',
    'toolsNotRunning',
    'toolsOk',
    'toolsOld',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class HostFirmwareSystem(BaseEntity):
    '''NOTE: This managed object type and all of its methods are experimental and
    subject to change in future releases.The FirmwareSystem managed object type
    provides access to the firmware of an embedded ESX host. It provides operations
    to backup/restore/reset the configuration of an embedded ESX host.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.HostFirmwareSystem):
        super(HostFirmwareSystem, self).__init__(core, name=name, ref=ref, type=type)

    

    
    
    def BackupFirmwareConfiguration(self):
        '''Backup the configuration of the host.Backup the configuration of the host.
        
        '''
        return self.delegate("BackupFirmwareConfiguration")()
    
    def QueryFirmwareConfigUploadURL(self):
        '''Return the URL on the host to which the configuration bundle must be uploaded
        for a restore operation.
        
        '''
        return self.delegate("QueryFirmwareConfigUploadURL")()
    
    def ResetFirmwareToFactoryDefaults(self):
        '''Reset the configuration to factory defaults.Reset the configuration to factory
        defaults.
        
        '''
        return self.delegate("ResetFirmwareToFactoryDefaults")()
    
    def RestoreFirmwareConfiguration(self, force):
        '''Restore the configuration of the host to that specified in the bundle.Restore
        the configuration of the host to that specified in the bundle.
        
        :param force: Forces application of the configuration even if the bundle is mismatched.
        
        '''
        return self.delegate("RestoreFirmwareConfiguration")(force)



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

PropertyChangeOp = Enum(
    'add',
    'assign',
    'indirectRemove',
    'remove',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

AgentInstallFailedReason = Enum(
    'AgentNotReachable',
    'AgentNotRunning',
    'AgentUploadFailed',
    'AgentUploadTimedout',
    'InstallTimedout',
    'NotEnoughSpaceOnDevice',
    'PrepareToUpgradeFailed',
    'SignatureVerificationFailed',
    'UnknownInstallerError',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def DistributedVirtualSwitchPortStatistics(vim, *args, **kwargs):
    '''Statistic data of a DistributedVirtualPort.'''

    obj = vim.client.factory.create('{urn:vim25}DistributedVirtualSwitchPortStatistics')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 16:
        raise IndexError('Expected at least 17 arguments got: %d' % len(args))

    required = [ 'bytesInBroadcast', 'bytesInMulticast', 'bytesInUnicast', 'bytesOutBroadcast',
        'bytesOutMulticast', 'bytesOutUnicast', 'packetsInBroadcast',
        'packetsInDropped', 'packetsInException', 'packetsInMulticast',
        'packetsInUnicast', 'packetsOutBroadcast', 'packetsOutDropped',
        'packetsOutException', 'packetsOutMulticast', 'packetsOutUnicast' ]
    optional = [ 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class HostEsxAgentHostManager(BaseEntity):
    '''This managed object type is used to configure agent virtual machine resource
    configuration, such as what network and datastore to use for agent virtual
    machines.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.HostEsxAgentHostManager):
        super(HostEsxAgentHostManager, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def configInfo(self):
        '''Configuration of agent virtual machine resources'''
        return self.update('configInfo')

    
    
    def EsxAgentHostManagerUpdateConfig(self, configInfo):
        '''Update the host's ESX agent configuration. The entire configuration must be set
        each time since all values are overwritten. E.g. a field set to null clears the
        value on the host.
        
        :param configInfo: configuration of agent virtual machine resources
        
        '''
        return self.delegate("EsxAgentHostManagerUpdateConfig")(configInfo)



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineGuestOsFamily = Enum(
    'darwinGuestFamily',
    'linuxGuest',
    'netwareGuest',
    'otherGuestFamily',
    'solarisGuest',
    'windowsGuest',

)




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class SoftwareProfile(Base):
    '''
    Display, install, update or validates image profiles
    '''
    moid = 'ha-cli-handler-software-profile'
    def validate(self, depot, profile, proxy=None):
        '''
        Validates the current image profile on the host against an image profile in a depot.
        :param depot: string[], Specifies full remote URLs of the depot index.xml or server file path pointing to an offline bundle .zip file.
        :param profile: string, Specifies the name of the image profile to validate the host with.
        :param proxy: string, Specifies a proxy server to use for HTTP, FTP, and HTTPS connections. The format is proxy-url:port.
        :returns: vim.EsxCLI.software.profile.validate.ProfileValidationResult
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.software.profile.Validate',
                            depot=depot,
                            profile=profile,
                            proxy=proxy,
                            )
    def update(self, depot, profile, allowdowngrades=None, dryrun=None, force=None, maintenancemode=None, noliveinstall=None, nosigcheck=None, proxy=None):
        '''
        Updates the host with VIBs from an image profile in a depot. Installed VIBs may be upgraded (or downgraded if --allow-downgrades is specified), but they will not be removed. Any VIBs in the image profile which are not related to any installed VIBs will be added to the host. WARNING: If your installation requires a reboot, you need to disable HA first.
        :param allowdowngrades: boolean, If this option is specified, then the VIBs from the image profile which update, downgrade, or are new to the host will be installed. If the option is not specified, then the VIBs which update or are new to the host will be installed.
        :param depot: string[], Specifies full remote URLs of the depot index.xml or server file path pointing to an offline bundle .zip file.
        :param dryrun: boolean, Performs a dry-run only. Report the VIB-level operations that would be performed, but do not change anything in the system.
        :param force: boolean, Bypasses checks for package dependencies, conflicts, obsolescence, and acceptance levels. Really not recommended unless you know what you are doing. Use of this option will result in a warning being displayed in the vSphere Client.
        :param maintenancemode: boolean, Pretends that maintenance mode is in effect. Otherwise, installation will stop for live installs that require maintenance mode. This flag has no effect for reboot required remediations.
        :param noliveinstall: boolean, Forces an install to /altbootbank even if the VIBs are eligible for live installation or removal. Will cause installation to be skipped on PXE-booted hosts.
        :param nosigcheck: boolean, Bypasses acceptance level verification, including signing. Use of this option poses a large security risk and will result in a SECURITY ALERT warning being displayed in the vSphere Client.
        :param profile: string, Specifies the name of the image profile to update the host with.
        :param proxy: string, Specifies a proxy server to use for HTTP, FTP, and HTTPS connections. The format is proxy-url:port.
        :returns: vim.EsxCLI.software.profile.update.InstallationResult
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.software.profile.Update',
                            allowdowngrades=allowdowngrades,
                            depot=depot,
                            dryrun=dryrun,
                            force=force,
                            maintenancemode=maintenancemode,
                            noliveinstall=noliveinstall,
                            nosigcheck=nosigcheck,
                            profile=profile,
                            proxy=proxy,
                            )
    def install(self, depot, profile, dryrun=None, force=None, maintenancemode=None, noliveinstall=None, nosigcheck=None, oktoremove=None, proxy=None):
        '''
        Installs or applies an image profile from a depot to this host. This command completely replaces the installed image with the image defined by the new image profile, and may result in the loss of installed VIBs. The common vibs between host and image profile will be skipped. To preserve installed VIBs, use profile update instead. WARNING: If your installation requires a reboot, you need to disable HA first.
        :param depot: string[], Specifies full remote URLs of the depot index.xml or server file path pointing to an offline bundle .zip file.
        :param dryrun: boolean, Performs a dry-run only. Report the VIB-level operations that would be performed, but do not change anything in the system.
        :param force: boolean, Bypasses checks for package dependencies, conflicts, obsolescence, and acceptance levels. Really not recommended unless you know what you are doing. Use of this option will result in a warning being displayed in the vSphere Client.
        :param maintenancemode: boolean, Pretends that maintenance mode is in effect. Otherwise, installation will stop for live installs that require maintenance mode. This flag has no effect for reboot required remediations.
        :param noliveinstall: boolean, Forces an install to /altbootbank even if the VIBs are eligible for live installation or removal. Will cause installation to be skipped on PXE-booted hosts.
        :param nosigcheck: boolean, Bypasses acceptance level verification, including signing. Use of this option poses a large security risk and will result in a SECURITY ALERT warning being displayed in the vSphere Client.
        :param oktoremove: boolean, Allows the removal of installed VIBs as part of applying the image profile. If not specified, esxcli will error out if applying the image profile results in the removal of installed VIBs.
        :param profile: string, Specifies the name of the image profile to install.
        :param proxy: string, Specifies a proxy server to use for HTTP, FTP, and HTTPS connections. The format is proxy-url:port.
        :returns: vim.EsxCLI.software.profile.install.InstallationResult
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.software.profile.Install',
                            depot=depot,
                            dryrun=dryrun,
                            force=force,
                            maintenancemode=maintenancemode,
                            noliveinstall=noliveinstall,
                            nosigcheck=nosigcheck,
                            oktoremove=oktoremove,
                            profile=profile,
                            proxy=proxy,
                            )
    def get(self, rebootingimage=None):
        '''
        Display the installed image profile and host acceptance level.
        :param rebootingimage: boolean, Displays information for the ESXi image which becomes active after a reboot, or nothing if the pending-reboot image has not been created yet.  If not specified, information from the current ESXi image in memory will be returned.
        :returns: vim.EsxCLI.software.profile.get.ImageProfile
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.software.profile.Get',
                            rebootingimage=rebootingimage,
                            )   



from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.managed_object_view import ManagedObjectView

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class ListView(ManagedObjectView):
    '''The ListView managed object provides access to updates on a specific set of
    objects. You can use a ListView with a PropertyCollector method to retrieve
    data or receive notification of changes. For information about using views with
    the PropertyCollector, see the description of ViewManager.When you invoke the
    CreateListView method, you specify a list of objects. The view list always
    represents the current configuration of the virtual environment and reflects
    any subsequent changes that occur.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.ListView):
        super(ListView, self).__init__(core, name=name, ref=ref, type=type)

    

    
    
    def ModifyListView(self, add=None, remove=None):
        '''Modify the list by giving a delta of entities to add and entities to
        remove.Modify the list by giving a delta of entities to add and entities to
        remove.
        
        :param add: Optional list of objects to add to the view.
        
        :param remove: Optional list of objects to remove from the view.
        
        '''
        return self.delegate("ModifyListView")(add, remove)
    
    def ResetListView(self, obj=None):
        '''Replaces the list with an entirely new set of objects. If the entire set is
        changing, this is less data to send than a delta.Replaces the list with an
        entirely new set of objects. If the entire set is changing, this is less data
        to send than a delta.
        
        :param obj: The new list of objects.
        
        '''
        return self.delegate("ResetListView")(obj)
    
    def ResetListViewFromView(self, view):
        '''Replaces the list with the set of objects in a given view.
        
        :param view: The view to copy objects from.
        
        '''
        return self.delegate("ResetListViewFromView")(view)



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ValidateMigrationTestType = Enum(
    'compatibilityTests',
    'diskAccessibilityTests',
    'resourceTests',
    'sourceTests',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def ActiveDirectoryProfile(vim, *args, **kwargs):
    '''The ActiveDirectoryProfile data object represents Active Directory
    configuration. Use the policy list for access to configuration data for the
    Active Directory profile. Use the property list for access to subprofiles, if
    any.'''

    obj = vim.client.factory.create('{urn:vim25}ActiveDirectoryProfile')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'enabled' ]
    optional = [ 'policy', 'profileTypeName', 'profileVersion', 'property', 'dynamicProperty',
        'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class FcoeNic(Base):
    '''
    Operations that can be performed on FCOE-capable CNA devices
    '''
    moid = 'ha-cli-handler-fcoe-nic'
    def disable(self, nicname):
        '''
        Disable rediscovery of FCOE storage on behalf of an FCOE-capable CNA upon next boot.
        :param nicname: string, The CNA adapter name (vmnicX)
        :returns: string
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.fcoe.nic.Disable',
                            nicname=nicname,
                            )
    def list(self):
        '''
        List FCOE-capable CNA devices.
        :returns: vim.EsxCLI.fcoe.nic.list.NicDevice[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.fcoe.nic.List',
                            )
    def discover(self, nicname):
        '''
        Initiate FCOE adapter discovery on behalf of an FCOE-capable CNA.
        :param nicname: string, The CNA adapter name (vmnicX)
        :returns: string
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.fcoe.nic.Discover',
                            nicname=nicname,
                            )   



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def DatastoreSummary(vim, *args, **kwargs):
    '''Summary information about the datastore. The status fields and managed object
    reference is not set when an object of this type is created. These fields and
    references are typically set later when these objects are associated with a
    host.'''

    obj = vim.client.factory.create('{urn:vim25}DatastoreSummary')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 6:
        raise IndexError('Expected at least 7 arguments got: %d' % len(args))

    required = [ 'accessible', 'capacity', 'freeSpace', 'name', 'type', 'url' ]
    optional = [ 'datastore', 'maintenanceMode', 'multipleHostAccess', 'uncommitted',
        'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

MetricAlarmOperator = Enum(
    'isAbove',
    'isBelow',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class HostDiagnosticSystem(BaseEntity):
    '''The DiagnosticSystem managed object is used to configure the diagnostic
    mechanisms specific to the host. The DiagnosticSystem interface supports the
    following concepts:* Notion of an active diagnostic partition that is selected
    from a set of available partitions. * Ability to create a diagnostic partition
    that gets added to the list of available partitions and could be made active.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.HostDiagnosticSystem):
        super(HostDiagnosticSystem, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def activePartition(self):
        '''The currently active diagnostic partition.'''
        return self.update('activePartition')

    
    
    def CreateDiagnosticPartition(self, spec):
        '''Creates a diagnostic partition according to the provided create specification.
        On success, this method will create the partition and make the partition the
        active diagnostic partition if specified. On failure, the diagnostic partition
        may exist but may not be active if the partition was supposed to be made
        active.
        
        :param spec: 
        
        '''
        return self.delegate("CreateDiagnosticPartition")(spec)
    
    def QueryAvailablePartition(self):
        '''Retrieves a list of available diagnostic partitions. The server will provide
        the list in order of preference. In general, local diagnostic partitions are
        better than shared diagnostic partitions because of the impossibility of
        multiple servers sharing the same partition. The most preferred diagnostic
        partition will be first in the array.
        
        '''
        return self.delegate("QueryAvailablePartition")()
    
    def QueryPartitionCreateDesc(self, diskUuid, diagnosticType):
        '''For a disk, query for the diagnostic partition creation description. The
        description details how the diagnostic partition will be created on the disk
        and provides a creation specification that is needed to invoke the create
        operation.See HostScsiDiskSee uuid
        
        :param diskUuid: See HostScsiDiskSee uuid
        
        :param diagnosticType: See HostScsiDiskSee uuid
        
        '''
        return self.delegate("QueryPartitionCreateDesc")(diskUuid, diagnosticType)
    
    def QueryPartitionCreateOptions(self, storageType, diagnosticType):
        '''Retrieves a list of disks that can be used to contain a diagnostic partition.
        This list will contain disks that have sufficient space to contain a diagnostic
        partition of the specific type.Retrieves a list of disks that can be used to
        contain a diagnostic partition. This list will contain disks that have
        sufficient space to contain a diagnostic partition of the specific type.
        
        :param storageType: 
        
        :param diagnosticType: 
        
        '''
        return self.delegate("QueryPartitionCreateOptions")(storageType, diagnosticType)
    
    def SelectActivePartition(self, partition=None):
        '''Changes the active diagnostic partition to a different partition. Setting a
        NULL partition will result in unsetting the diagnostic partition.
        
        :param partition: 
        
        '''
        return self.delegate("SelectActivePartition")(partition)



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineConfigInfoSwapPlacementType = Enum(
    'hostLocal',
    'inherit',
    'vmDirectory',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ThinProvisioningStatus = Enum(
    'GREEN',
    'RED',
    'YELLOW',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.managed_entity import ManagedEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class Network(ManagedEntity):
    '''Represents a network accessible by either hosts or virtual machines. This can
    be a physical network or a logical network, such as a VLAN.Networks are
    created:* explicitly when configuring a host. * automatically when adding a
    host to VirtualCenter. * automatically when adding a new virtual machine to a
    host or to VirtualCenter.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.Network):
        super(Network, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def host(self):
        '''Hosts attached to this network.'''
        return self.update('host')
    @property
    def name(self):
        '''Name of this network.'''
        return self.update('name')
    @property
    def summary(self):
        '''Properties of a network.'''
        return self.update('summary')
    @property
    def vm(self):
        '''Virtual machines using this network.'''
        return self.update('vm')

    
    
    def DestroyNetwork(self):
        '''<b>Deprecated.</b> <i>As of VI API 2.5 do not use this method. This method
        throws ResourceInUse. Networks are automatically removed when no longer in use,
        so this method is unnecessary.</i> Removes a network. A network can be removed
        only if it is not used by any host or virtual machine.
        
        '''
        return self.delegate("DestroyNetwork")()



from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class HardwareCpuCpuid(Base):
    '''
    Information from the CPUID instruction on each CPU.
    '''
    moid = 'ha-cli-handler-hardware-cpu-cpuid'
    def get(self, cpu):
        '''
        Get CPUID fields for the given CPU.
        :param cpu: long, The ID of the CPU to query for CPUID data
        :returns: vim.EsxCLI.hardware.cpu.cpuid.get.CpuCpuId[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.hardware.cpu.cpuid.Get',
                            cpu=cpu,
                            )   



from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class HostDateTimeSystem(BaseEntity):
    '''This managed object provides for NTP and date/time related configuration on a
    host. Information regarding the running status of the NTP daemon and
    functionality to start and stop the daemon is provided by the HostServiceSystem
    object.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.HostDateTimeSystem):
        super(HostDateTimeSystem, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def dateTimeInfo(self):
        '''The DateTime configuration of the host.'''
        return self.update('dateTimeInfo')

    
    
    def QueryAvailableTimeZones(self):
        '''Retrieves the list of available timezones on the host. The API works off the
        public domain 'tz' timezone database.
        
        '''
        return self.delegate("QueryAvailableTimeZones")()
    
    def QueryDateTime(self):
        '''Get the current DateTime on the host.
        
        '''
        return self.delegate("QueryDateTime")()
    
    def RefreshDateTimeSystem(self):
        '''Refresh the DateTime related settings to pick up any changes that might have
        occurred.
        
        '''
        return self.delegate("RefreshDateTimeSystem")()
    
    def UpdateDateTime(self, dateTime):
        '''Update the date/time on the host. This method should be used with caution since
        network delays, execution delays can result in time skews.
        
        :param dateTime: DateTime to update the host to.
        
        '''
        return self.delegate("UpdateDateTime")(dateTime)
    
    def UpdateDateTimeConfig(self, config):
        '''Update the DateTime configuration of the host.
        
        :param config: The new DateTime configuration information.
        
        '''
        return self.delegate("UpdateDateTimeConfig")(config)



from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class SystemCoredumpNetwork(Base):
    '''
    Operations pertaining to the VMkernel Core dump configuration on network dump servers. 
    '''
    moid = 'ha-cli-handler-system-coredump-network'
    def set(self, enable=None, interfacename=None, serveripv4=None, serverport=None):
        '''
        Set the parameters used for network core dump
        :param enable: boolean, Enable network dump. This option cannot be specified when setting the dump parameters below.
        :param interfacename: string, An active interface to be used for the network core dump. Required option when setting dump parameters.
        :param serveripv4: string, IP address of the core dump server. Required option when setting dump parameters.
        :param serverport: long, Port on which the core dump server is listening. (Optional)
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.system.coredump.network.Set',
                            enable=enable,
                            interfacename=interfacename,
                            serveripv4=serveripv4,
                            serverport=serverport,
                            )
    def get(self):
        '''
        Get the currently configured parameters for network coredump, if enabled.
        :returns: vim.EsxCLI.system.coredump.network.get.NetworkCoredump
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.system.coredump.network.Get',
                            )   



from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class NetworkVswitchStandardUplink(Base):
    '''
    Commands to add and remove uplink on given virtual switch.
    '''
    moid = 'ha-cli-handler-network-vswitch-standard-uplink'
    def add(self, uplinkname, vswitchname):
        '''
        Add an uplink to the given virtual switch. Note if this virtual switch has a NIC teaming policy assigned to it then the policy must also be modified to enable use of this uplink on this virtual switch
        :param uplinkname: string, The name of the uplink to add to the virtual switch.
        :param vswitchname: string, The name of the virtual switch to add an uplink to.
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.vswitch.standard.uplink.Add',
                            uplinkname=uplinkname,
                            vswitchname=vswitchname,
                            )
    def remove(self, uplinkname, vswitchname):
        '''
        Remove an uplink from the given virtual switch. Note if this virtual switch has a NIC teaming policy assigned to it then the policy must also be modified to disable use of this uplink on this virtual switch
        :param uplinkname: string, The name of the uplink to remove from the virtual switch.
        :param vswitchname: string, The name of the virtual switch to remove an uplink from.
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.vswitch.standard.uplink.Remove',
                            uplinkname=uplinkname,
                            vswitchname=vswitchname,
                            )   



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def SnapshotRevertIssue(vim, *args, **kwargs):
    '''If the virtual machine is migrated to the destination host, there may be a
    problem reverting to one of its snapshots. This is a warning. If the snapshot
    name is not set and the event array is empty, then it the snapshot might
    possibly revert correctly. If the name is set and the event array is not empty
    then there surely will be a problem reverting to the snapshot.'''

    obj = vim.client.factory.create('{urn:vim25}SnapshotRevertIssue')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 7:
        raise IndexError('Expected at least 8 arguments got: %d' % len(args))

    required = [ 'errors', 'event', 'snapshotName', 'dynamicProperty', 'dynamicType',
        'faultCause', 'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualMachineConfigSpecNpivWwnOp = Enum(
    'extend',
    'generate',
    'remove',
    'set',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class SmsTask(BaseEntity):
    '''A task is used to monitor long running operations.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.SmsTask):
        super(SmsTask, self).__init__(core, name=name, ref=ref, type=type)

    

    
    
    def QuerySmsTaskInfo(self):
        '''Get detailed information about this task.
        
        '''
        return self.delegate("QuerySmsTaskInfo")()
    
    def QuerySmsTaskResult(self):
        '''Get the result of the task.
        
        '''
        return self.delegate("QuerySmsTaskResult")()



from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class HardwareCpuGlobal(Base):
    '''
    Information and configuration global to all CPUs.
    '''
    moid = 'ha-cli-handler-hardware-cpu-global'
    def set(self, hyperthreading):
        '''
        Set properties that are global to all CPUs.
        :param hyperthreading: boolean, Enable or disable hyperthreading
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.hardware.cpu.global.Set',
                            hyperthreading=hyperthreading,
                            )
    def get(self):
        '''
        Get properties that are global to all CPUs.
        :returns: vim.EsxCLI.hardware.cpu.global.get.Cpu
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.hardware.cpu.global.Get',
                            )   



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostImageAcceptanceLevel = Enum(
    'community',
    'partner',
    'vmware_accepted',
    'vmware_certified',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def ReadHostResourcePoolTreeFailed(vim, *args, **kwargs):
    '''Fault thrown on host connect if we were unable to correctly read the existing
    tree on the root. This is bad because then we don't know the available
    resources on the host, and all kinds of admission control will fail. This just
    allows for more robust error handling - we should be able to read the existing
    hierarchy under normal conditions.'''

    obj = vim.client.factory.create('{urn:vim25}ReadHostResourcePoolTreeFailed')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 4:
        raise IndexError('Expected at least 5 arguments got: %d' % len(args))

    required = [ 'dynamicProperty', 'dynamicType', 'faultCause', 'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.extensible_managed_object import ExtensibleManagedObject

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class HostNetworkSystem(ExtensibleManagedObject):
    '''This managed object type describes networking host configuration and serves as
    the top level container for relevant networking data objects.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.HostNetworkSystem):
        super(HostNetworkSystem, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def capabilities(self):
        '''Capability vector indicating the available product features.'''
        return self.update('capabilities')
    @property
    def consoleIpRouteConfig(self):
        '''IP route configuration for the service console. The IP route configuration is
        global to the entire host. This property is set only if IP routing can be
        configured for the service console.'''
        return self.update('consoleIpRouteConfig')
    @property
    def dnsConfig(self):
        '''Client-side DNS configuration for the host. The DNS configuration is global to
        the entire host. This is set only if DNS can be configured for the host.'''
        return self.update('dnsConfig')
    @property
    def ipRouteConfig(self):
        '''The IP route configuration for the host. The IP route configuration is global
        to the entire host. This property is set only if IP routing can be configured
        for the host.'''
        return self.update('ipRouteConfig')
    @property
    def networkConfig(self):
        '''Network configuration information. This information can be applied using the
        updateNetworkConfig() method. The information is a strict subset of the
        information available in NetworkInfo.See HostNetworkInfo'''
        return self.update('networkConfig')
    @property
    def networkInfo(self):
        '''The network configuration and runtime information.'''
        return self.update('networkInfo')
    @property
    def offloadCapabilities(self):
        '''The offload capabilities available on this server.'''
        return self.update('offloadCapabilities')

    
    
    def AddPortGroup(self, portgrp):
        '''Adds a port group to the virtual switch.
        
        :param portgrp: 
        
        '''
        return self.delegate("AddPortGroup")(portgrp)
    
    def AddServiceConsoleVirtualNic(self, portgroup, nic):
        '''Adds a virtual service console network adapter. Returns the device of the
        VirtualNic.Adds a virtual service console network adapter. Returns the device
        of the VirtualNic.
        
        :param portgroup: See usesServiceConsoleNic
        
        :param nic: See usesServiceConsoleNic
        
        '''
        return self.delegate("AddServiceConsoleVirtualNic")(portgroup, nic)
    
    def AddVirtualNic(self, portgroup, nic):
        '''Adds a virtual host/VMkernel network adapter. Returns the device of the virtual
        network adapter.Adds a virtual host/VMkernel network adapter. Returns the
        device of the virtual network adapter.
        
        :param portgroup: Note: Must be the empty string in case nic.distributedVirtualPort is set.
        
        :param nic: 
        
        '''
        return self.delegate("AddVirtualNic")(portgroup, nic)
    
    def AddVirtualSwitch(self, vswitchName, spec=None):
        '''Adds a new virtual switch to the system with the given name. The name must be
        unique with respect to other virtual switches on the host and is limited to 32
        characters.See UpdateVirtualSwitch
        
        :param vswitchName: See UpdateVirtualSwitch
        
        :param spec: See UpdateVirtualSwitch
        
        '''
        return self.delegate("AddVirtualSwitch")(vswitchName, spec)
    
    def QueryNetworkHint(self, device=None):
        '''Requests network hint information for a physical network adapter. A network
        hint is some information about the network to which the physical network
        adapter is attached. The method receives in a list of physical network adapter
        devices and returns an equal number of hints if some devices are provided. If
        the list of devices is empty, then the method accesses hints for all physical
        network adapters.See supportsNetworkHintsSee device
        
        :param device: See supportsNetworkHintsSee device
        
        '''
        return self.delegate("QueryNetworkHint")(device)
    
    def RefreshNetworkSystem(self):
        '''Refresh the network information and settings to pick up any changes that might
        have occurred.
        
        '''
        return self.delegate("RefreshNetworkSystem")()
    
    def RemovePortGroup(self, pgName):
        '''Removes port group from the virtual switch.
        
        :param pgName: 
        
        '''
        return self.delegate("RemovePortGroup")(pgName)
    
    def RemoveServiceConsoleVirtualNic(self, device):
        '''Removes a virtual service console network adapter.See usesServiceConsoleNic
        
        :param device: See usesServiceConsoleNic
        
        '''
        return self.delegate("RemoveServiceConsoleVirtualNic")(device)
    
    def RemoveVirtualNic(self, device):
        '''Removes a virtual host/VMkernel network adapter.
        
        :param device: 
        
        '''
        return self.delegate("RemoveVirtualNic")(device)
    
    def RemoveVirtualSwitch(self, vswitchName):
        '''Removes an existing virtual switch from the system.
        
        :param vswitchName: 
        
        '''
        return self.delegate("RemoveVirtualSwitch")(vswitchName)
    
    def RestartServiceConsoleVirtualNic(self, device):
        '''Restart the service console virtual network adapter interface. If the service
        console virtual network adapter uses DHCP, restarting the interface may result
        it with a different IP configuration, or even fail to be brought up depending
        on the host system network configuration.See usesServiceConsoleNic
        
        :param device: See usesServiceConsoleNic
        
        '''
        return self.delegate("RestartServiceConsoleVirtualNic")(device)
    
    def UpdateConsoleIpRouteConfig(self, config):
        '''Applies the IP route configuration for the service console.
        
        :param config: 
        
        '''
        return self.delegate("UpdateConsoleIpRouteConfig")(config)
    
    def UpdateDnsConfig(self, config):
        '''Applies the client-side DNS configuration for the host.
        
        :param config: 
        
        '''
        return self.delegate("UpdateDnsConfig")(config)
    
    def UpdateIpRouteConfig(self, config):
        '''Applies the IP route configuration for the host.
        
        :param config: 
        
        '''
        return self.delegate("UpdateIpRouteConfig")(config)
    
    def UpdateIpRouteTableConfig(self, config):
        '''Applies the IP route table configuration for the host.
        
        :param config: 
        
        '''
        return self.delegate("UpdateIpRouteTableConfig")(config)
    
    def UpdateNetworkConfig(self, config, changeMode):
        '''Applies the network configuration. This method operates primarily in two modes:
        <b>replace</b> or <b>modify</b> mode.
        
        :param config: See HostConfigChangeMode
        
        :param changeMode: See HostConfigChangeMode
        
        '''
        return self.delegate("UpdateNetworkConfig")(config, changeMode)
    
    def UpdatePhysicalNicLinkSpeed(self, device, linkSpeed=None):
        '''Configures link speed and duplexity. If linkSpeed is not specified, physical
        network adapter will be set to autonegotiate.See canSetPhysicalNicLinkSpeed
        
        :param device: See canSetPhysicalNicLinkSpeed
        
        :param linkSpeed: See canSetPhysicalNicLinkSpeed
        
        '''
        return self.delegate("UpdatePhysicalNicLinkSpeed")(device, linkSpeed)
    
    def UpdatePortGroup(self, pgName, portgrp):
        '''Reconfigures a port group on the virtual switch.
        
        :param pgName: 
        
        :param portgrp: 
        
        '''
        return self.delegate("UpdatePortGroup")(pgName, portgrp)
    
    def UpdateServiceConsoleVirtualNic(self, device, nic):
        '''Configures the IP configuration for a virtual service console network
        adapter.Configures the IP configuration for a virtual service console network
        adapter.
        
        :param device: See usesServiceConsoleNic
        
        :param nic: See usesServiceConsoleNic
        
        '''
        return self.delegate("UpdateServiceConsoleVirtualNic")(device, nic)
    
    def UpdateVirtualNic(self, device, nic):
        '''Configures virtual host/VMkernel network adapter.Configures virtual
        host/VMkernel network adapter.
        
        :param device: 
        
        :param nic: 
        
        '''
        return self.delegate("UpdateVirtualNic")(device, nic)
    
    def UpdateVirtualSwitch(self, vswitchName, spec):
        '''Updates the properties of the virtual switch.Updates the properties of the
        virtual switch.Updates the properties of the virtual switch.Updates the
        properties of the virtual switch.
        
        :param vswitchName: See HostNicOrderPolicy
        
        :param spec: See HostNicOrderPolicy
        
        '''
        return self.delegate("UpdateVirtualSwitch")(vswitchName, spec)



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

OvfCreateImportSpecParamsDiskProvisioningType = Enum(
    'eagerZeroedThick',
    'flat',
    'monolithicFlat',
    'monolithicSparse',
    'sparse',
    'thick',
    'thin',
    'twoGbMaxExtentFlat',
    'twoGbMaxExtentSparse',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DayOfWeek = Enum(
    'friday',
    'monday',
    'saturday',
    'sunday',
    'thursday',
    'tuesday',
    'wednesday',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def FileQueryFlags(vim, *args, **kwargs):
    '''The FileInfo.Details data object type is a set of flags for a search request.
    This search request specifies which details to return for each matching file.
    This data object type is here to ensure that there is one flag corresponding to
    each FileInfo property other than the path name, which a search always returns.'''

    obj = vim.client.factory.create('{urn:vim25}FileQueryFlags')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 4:
        raise IndexError('Expected at least 5 arguments got: %d' % len(args))

    required = [ 'fileOwner', 'fileSize', 'fileType', 'modification' ]
    optional = [ 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class HostBootDeviceSystem(BaseEntity):
    '''The HostBootDeviceSystem managed object provides methods to query and update a
    host boot device configuration.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.HostBootDeviceSystem):
        super(HostBootDeviceSystem, self).__init__(core, name=name, ref=ref, type=type)

    

    
    
    def QueryBootDevices(self):
        '''Retrieves a list of the available boot devices for the host system.
        
        '''
        return self.delegate("QueryBootDevices")()
    
    def UpdateBootDevice(self, key):
        '''Sets the current boot device for the host system.
        
        :param key: The key of the HostBootDevice from which the host will boot.
        
        '''
        return self.delegate("UpdateBootDevice")(key)



from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class IscsiAdapterTargetPortal(Base):
    '''
    Operations that can be performed on iSCSI target portal
    '''
    moid = 'ha-cli-handler-iscsi-adapter-target-portal'
    def list(self, adapter=None, name=None):
        '''
        List iSCSI target portals.
        :param adapter: string, The iSCSI adapter name.
        :param name: string, The iSCSI target name.
        :returns: vim.EsxCLI.iscsi.adapter.target.portal.list.TargetPortal[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.iscsi.adapter.target.portal.List',
                            adapter=adapter,
                            name=name,
                            )   



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def IpPoolIpPoolConfigInfo(vim, *args, **kwargs):
    '''Specifications of either IPv4 or IPv6 configuration to be used on this network.
    This is a part of network configuration.IPv4 addresses are in dot-decimal
    notation, e.g.: 192.0.2.235IPv6 addresses are in colon-hexadecimal notation,
    e.g.: 2001:0db8:85a3::0370:7334'''

    obj = vim.client.factory.create('{urn:vim25}IpPoolIpPoolConfigInfo')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 0:
        raise IndexError('Expected at least 1 arguments got: %d' % len(args))

    required = [  ]
    optional = [ 'dhcpServerAvailable', 'dns', 'gateway', 'ipPoolEnabled', 'netmask', 'range',
        'subnetAddress', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def TicketedSessionAuthentication(vim, *args, **kwargs):
    '''TicketedSessionAuthentication contains the information necessary to use
    previously obtained credentials in the guest. The ticketed session is not
    stateless and stores state inside of the guest.A TicketedSessionAuthentication
    object will be returned as the result of a successful call to
    AcquireCredentialsInGuest. You can use this object in any guest operations
    function call.When you no longer need the TicketedSessionAuthentication object,
    you should call ReleaseCredentialsInGuest to free associated resources and
    session data.'''

    obj = vim.client.factory.create('{urn:vim25}TicketedSessionAuthentication')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 2:
        raise IndexError('Expected at least 3 arguments got: %d' % len(args))

    required = [ 'ticket', 'interactiveSession' ]
    optional = [ 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from ..thirdparty import Enum

ManagedObjectTypes = Enum(
    "ReflectManagedMethodExecuter",
    "InternalDynamicTypeManager",
    "Alarm",
    "AlarmManager",
    "AuthorizationManager",
    "ClusterComputeResource",
    "ClusterProfile",
    "ClusterProfileManager",
    "ComputeResource",
    "ContainerView",
    "CustomFieldsManager",
    "CustomizationSpecManager",
    "Datacenter",
    "Datastore",
    "DiagnosticManager",
    "DistributedVirtualPortgroup",
    "DistributedVirtualSwitch",
    "DistributedVirtualSwitchManager",
    "EnvironmentBrowser",
    "EventHistoryCollector",
    "EventManager",
    "ExtensibleManagedObject",
    "ExtensionManager",
    "FileManager",
    "Folder",
    "GuestAuthManager",
    "GuestFileManager",
    "GuestOperationsManager",
    "GuestProcessManager",
    "HistoryCollector",
    "HostActiveDirectoryAuthentication",
    "HostAuthenticationManager",
    "HostAuthenticationStore",
    "HostAutoStartManager",
    "HostBootDeviceSystem",
    "HostCacheConfigurationManager",
    "HostCpuSchedulerSystem",
    "HostDatastoreBrowser",
    "HostDatastoreSystem",
    "HostDateTimeSystem",
    "HostDiagnosticSystem",
    "HostDirectoryStore",
    "HostEsxAgentHostManager",
    "HostFirewallSystem",
    "HostFirmwareSystem",
    "HostHealthStatusSystem",
    "HostImageConfigManager",
    "HostKernelModuleSystem",
    "HostLocalAccountManager",
    "HostLocalAuthentication",
    "HostMemorySystem",
    "HostNetworkSystem",
    "HostPatchManager",
    "HostPciPassthruSystem",
    "HostPowerSystem",
    "HostProfile",
    "HostProfileManager",
    "HostServiceSystem",
    "HostSnmpSystem",
    "HostStorageSystem",
    "HostSystem",
    "HostVMotionSystem",
    "HostVirtualNicManager",
    "HttpNfcLease",
    "InventoryView",
    "IpPoolManager",
    "IscsiManager",
    "LicenseAssignmentManager",
    "LicenseManager",
    "ListView",
    "LocalizationManager",
    "ManagedEntity",
    "ManagedObjectView",
    "Network",
    "OptionManager",
    "OvfManager",
    "PerformanceManager",
    "Profile",
    "ProfileComplianceManager",
    "ProfileManager",
    "PropertyCollector",
    "PropertyFilter",
    "ResourcePlanningManager",
    "ResourcePool",
    "ScheduledTask",
    "ScheduledTaskManager",
    "SearchIndex",
    "ServiceInstance",
    "SessionManager",
    "StoragePod",
    "StorageResourceManager",
    "Task",
    "TaskHistoryCollector",
    "TaskManager",
    "UserDirectory",
    "View",
    "ViewManager",
    "VirtualApp",
    "VirtualDiskManager",
    "VirtualMachine",
    "VirtualMachineCompatibilityChecker",
    "VirtualMachineProvisioningChecker",
    "VirtualMachineSnapshot",
    "VirtualizationManager",
    "VmwareDistributedVirtualSwitch",
    "SmsProvider",
    "SmsServiceInstance",
    "SmsStorageManager",
    "SmsTask",
    "VasaProvider"
)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostCapabilityFtUnsupportedReason = Enum(
    'ftNotLicensed',
    'haAgentIssue',
    'missingFTLoggingNic',
    'missingVMotionNic',
    'vMotionNotLicensed',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DVPortStatusVmDirectPathGen2InactiveReasonOther = Enum(
    'portNptIncompatibleConnectee',
    'portNptIncompatibleHost',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.extensible_managed_object import ExtensibleManagedObject

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class HostFirewallSystem(ExtensibleManagedObject):
    '''The FirewallSystem managed object describes the firewall configuration of the
    host.The firewall should be configured first by setting the default policy and
    then by making exceptions to the policy to get the desired openness.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.HostFirewallSystem):
        super(HostFirewallSystem, self).__init__(core, name=name, ref=ref, type=type)

    
    @property
    def firewallInfo(self):
        '''Firewall configuration.'''
        return self.update('firewallInfo')

    
    
    def DisableRuleset(self, id):
        '''Blocks the firewall ports belonging to the specified ruleset. If the ruleset
        has a managed service with a policy of 'auto' and all other rulesets used by
        the service are blocked, stops the service.
        
        :param id: 
        
        '''
        return self.delegate("DisableRuleset")(id)
    
    def EnableRuleset(self, id):
        '''Opens the firewall ports belonging to the specified ruleset. If the ruleset has
        a managed service with a policy of 'auto' that is not running, starts the
        service.
        
        :param id: 
        
        '''
        return self.delegate("EnableRuleset")(id)
    
    def RefreshFirewall(self):
        '''Refresh the firewall information and settings to pick up any changes made
        directly on the host.
        
        '''
        return self.delegate("RefreshFirewall")()
    
    def UpdateDefaultPolicy(self, defaultPolicy):
        '''Updates the default firewall policy; unset fields are left unchanged.
        
        :param defaultPolicy: 
        
        '''
        return self.delegate("UpdateDefaultPolicy")(defaultPolicy)
    
    def UpdateRuleset(self, id, spec):
        '''Update the firewall ruleset specification.
        
        :param id: 
        
        :param spec: 
        
        '''
        return self.delegate("UpdateRuleset")(id, spec)



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

FileSystemInterfaceVersion = Enum(
    'NFSV3_0',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def DestinationSwitchFull(vim, *args, **kwargs):
    '''For one of the networks that the virtual machine is using, the corresponding
    switch on the host is full. If returned as part of migration checks, this is an
    error if either of the following is true, a warning otherwise:'''

    obj = vim.client.factory.create('{urn:vim25}DestinationSwitchFull')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 7:
        raise IndexError('Expected at least 8 arguments got: %d' % len(args))

    required = [ 'backing', 'connected', 'device', 'dynamicProperty', 'dynamicType',
        'faultCause', 'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def VmPortGroupProfile(vim, *args, **kwargs):
    '''The VmPortGroupProfile data object represents the subprofile for a port group
    that will be used by virtual machines. Use the policy list for access to
    configuration data for the virtual machine port group profile. Use the property
    list for access to subprofiles, if any.vSphere Servers use Network managed
    objects to represent virtual machine port groups in the vSphere inventory.'''

    obj = vim.client.factory.create('{urn:vim25}VmPortGroupProfile')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 6:
        raise IndexError('Expected at least 7 arguments got: %d' % len(args))

    required = [ 'key', 'name', 'networkPolicy', 'vlan', 'vswitch', 'enabled' ]
    optional = [ 'policy', 'profileTypeName', 'profileVersion', 'property', 'dynamicProperty',
        'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

ThirdPartyLicenseAssignmentFailedReason = Enum(
    'licenseAssignmentFailed',
    'moduleNotInstalled',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

SessionManagerHttpServiceRequestSpecMethod = Enum(
    'httpConnect',
    'httpDelete',
    'httpGet',
    'httpHead',
    'httpOptions',
    'httpPost',
    'httpPut',
    'httpTrace',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostInternetScsiHbaChapAuthenticationType = Enum(
    'chapDiscouraged',
    'chapPreferred',
    'chapProhibited',
    'chapRequired',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

SmsTaskState = Enum(
    'error',
    'running',
    'success',

)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

NumVirtualCpusIncompatibleReason = Enum(
    'faultTolerance',
    'recordReplay',

)



import os.path
from pyvisdk.thirdparty import Enum

vi_options = Enum(
    "VI_CONFIG", "VI_PASSWORD", "VI_PORTNUMBER", "VI_PROTOCOL", "VI_SERVER", "VI_SERVICEPATH", "VI_SESSIONFILE",
    "VI_URL", "VI_USERNAME", "VI_VERBOSE",
    "VI_EXTENSION_CERTIFICATE", "VI_EXTENSION_PRIVATEKEY", "VI_EXTENSION_KEY")

class Options(object):
    '''
    Options for pyvisdk that will read in the .visdkrc files
    '''
    def __init__(self, **kw):
        '''
        Constructor
        '''
        # default filename...
        self.filename = os.path.expanduser("~/.visdkrc")

        self.vals = {
            str(vi_options.VI_SERVER): 'localhost',
            str(vi_options.VI_USERNAME): 'root',
            str(vi_options.VI_PASSWORD): 'password',
            str(vi_options.VI_URL): 'https://localhost/sdk',
        }
        if kw:
            self.update(kw)
        self.file_changed = False

    def __del__(self):
        if self.file_changed:
            self.save()

    def __getattr__(self, attr):
        return self.vals.get(attr, "")

    def __iter__(self):
        def do_iter():
            for key in self.vals:
                yield key, self[key]
        return do_iter()

    def __getitem__(self, attr):
        return self.__getattr__(attr)

    def __setitem__(self, attr, val):
        self.vals[attr] = str(val)
        self.file_changed = True

    def update(self, d):
        self.vals.update(d)

    def load(self, filename=None):
        """ Load saved options from a file.  The format is explained in the `Perl Toolkit Programming Guide, table 1`_ .
        Most variables are supported, where appropriate.
        
        Currently only VI_SERVER, VI_USERNAME, and VI_PASSWORD are supported.  More to follow...
        
        :param filename: `Optional` The filename to load.  Defaults to ~/.visdkrc.
        
        .. _Perl Toolkit Programming Guide, table 1: http://www.vmware.com/support/developer/viperltoolkit/doc/perl_toolkit_guide.html#table1
        """
        if filename:
            self.filename = os.path.expanduser(filename)
            self._read()
        else:
            if os.path.exists(self.filename):
                self._read()

    def load_env(self):
        for var in os.environ.items():
           if var in vi_options:
               self.vals[var] = os.environ[var]

    def _read(self):
        for line in open(self.filename).readlines():
            if line[0] == '#':
                continue
            name, value = line.split("=")
            self.vals[name.strip()] = value.strip()

    def save(self):
        if self.file_changed:
            outfile = open(self.filename, 'w')
            for n, v in self.vals.items():
                outfile.writeline("%s=%s" % (n, v))
            outfile.close()

    def __str__(self):
        return str(self.vals)











########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

EventCategory = Enum(
    'error',
    'info',
    'user',
    'warning',

)




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class StorageCoreDeviceWorld(Base):
    '''
    Operations on worlds pertaining to the pluggable storage architectures' logical devices on the system. 
    '''
    moid = 'ha-cli-handler-storage-core-device-world'
    def list(self, device=None):
        '''
        Get a list of the worlds that are currently using devices on the ESX host.
        :param device: string, Filter the output of the command to limit the output to a specific device.  This device name can be any of the UIDs registered for a device.
        :returns: vim.EsxCLI.storage.core.device.world.list.ScsiDeviceWorld[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.core.device.world.List',
                            device=device,
                            )   



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def ClusterVmToolsMonitoringSettings(vim, *args, **kwargs):
    '''vSphere HA Virtual Machine Health Monitoring service setting.Virtual Machine
    Health Monitoring service checks the VMware Tools heartbeat of a virtual
    machine. If heartbeats have not been received within a specified time interval,
    Virtual Machine Health Monitoring service declares the virtual machine as
    failed and resets the virtual machine.VmToolsMonitoringSetting consists of
    configuration settings for Virtual Machine Health Monitoring Service.All fields
    are defined as optional. In case of a reconfiguration, fields left unset are
    not changed.'''

    obj = vim.client.factory.create('{urn:vim25}ClusterVmToolsMonitoringSettings')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 0:
        raise IndexError('Expected at least 1 arguments got: %d' % len(args))

    required = [  ]
    optional = [ 'clusterSettings', 'enabled', 'failureInterval', 'maxFailures',
        'maxFailureWindow', 'minUpTime', 'vmMonitoring', 'dynamicProperty',
        'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class NetworkVswitchStandardPolicyFailover(Base):
    '''
    Commands to manipulate failover policy setting for the given virtual switch.
    '''
    moid = 'ha-cli-handler-network-vswitch-standard-policy-failover'
    def set(self, vswitchname, activeuplinks=None, failback=None, failuredetection=None, loadbalancing=None, notifyswitches=None, standbyuplinks=None):
        '''
        Configure the Failover policy for a virtual switch.
        :param activeuplinks: string, Configure the list of active adapters and their failover order. This list must be a comma seperated list of values with the uplink name and no spaces. Example:  --active-uplinks=vmnic0,vmnic3,vmnic7,vmnic1
        :param failback: boolean, Configure whether a NIC will be used immediately when it comes back in service after a failover
        :param failuredetection: string, Set the method of determining how a network outage is detected. 
    beacon: Detect failures based on active beaconing to the vswitch
    link: Detect failures based on the NIC link state

        :param loadbalancing: string, Set the load balancing policy for this policy. This can be one of the following options: 
    explicit: Always use the highest order uplink from the list of active adapters which pass failover criteria.
    iphash: Route based on hashing the src and destination IP addresses
    mac: Route based on the MAC address of the packet source.
    portid: Route based on the originating virtual port ID.

        :param notifyswitches: boolean, Indicate whether to send a notification to physical switches on failover
        :param standbyuplinks: string, Configure the list of standby adapters and their failover order. This list must be a comma seperated list of values with the uplink name and no spaces. Example:  --standby-uplinks=vmnic2,vmnic4,vmnic8,vmnic6,vmnic11
        :param vswitchname: string, The name of the virtual switch to use when configuring the switch failover policy.
        :returns: boolean
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.vswitch.standard.policy.failover.Set',
                            activeuplinks=activeuplinks,
                            failback=failback,
                            failuredetection=failuredetection,
                            loadbalancing=loadbalancing,
                            notifyswitches=notifyswitches,
                            standbyuplinks=standbyuplinks,
                            vswitchname=vswitchname,
                            )
    def get(self, vswitchname):
        '''
        Get the failover policy settings governing the given virtual switch
        :param vswitchname: string, The name of the virtual switch to use when fetching the switch failover policy.
        :returns: vim.EsxCLI.network.vswitch.standard.policy.failover.get.VirtualSwitchFailoverPolicy
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.network.vswitch.standard.policy.failover.Get',
                            vswitchname=vswitchname,
                            )   



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def NetworkProfileDnsConfigProfile(vim, *args, **kwargs):
    '''The NetworkProfileDnsConfigProfile data object represents DNS configuration for
    the host. Use the policy list for access to configuration data for the DNS
    profile. Use the property list for access to subprofiles, if any.'''

    obj = vim.client.factory.create('{urn:vim25}NetworkProfileDnsConfigProfile')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'enabled' ]
    optional = [ 'policy', 'profileTypeName', 'profileVersion', 'property', 'dynamicProperty',
        'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

DiagnosticPartitionType = Enum(
    'multiHost',
    'singleHost',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def WillLoseHAProtection(vim, *args, **kwargs):
    '''This fault is reported when the execution of a storage vmotion or relocate
    operation would impact vSphere HA's ability to restart a VM. For storage
    vmotion, this fault is reported when HA protection will be lost after the
    vmotion completes. Consequently, HA would not restart the VM if it subsequently
    failed. For relocate, relocate is not supported on VMs that failed before the
    operation is attempted and are in the process of being restarted at the time
    the operation is performed.'''

    obj = vim.client.factory.create('{urn:vim25}WillLoseHAProtection')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 5:
        raise IndexError('Expected at least 6 arguments got: %d' % len(args))

    required = [ 'resolution', 'dynamicProperty', 'dynamicType', 'faultCause', 'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostServiceTicket(vim, *args, **kwargs):
    '''Return value for ticketable host services. The server has the option to provide
    a hostname and port for a future ticket-authenticated connection to a service
    on a host. If the service provider does not return a host the client must
    connect to the same host it used to request the ticket. In case the service
    provider does not return a port, except in the case of connecting to CIM
    interfaces, the client must connect using the same port it used to request the
    ticket. In the case of connecting to a CIM interface the standard well known
    port number for the particular service will be used for the connection.For
    example, when a client requests a ticket from an ESX Server, the returned
    ticket may omit the optional host and port. In such a case, the client
    establishes an out-of-band ticketed connection to the same server host and on
    the same port on which it made the connection to request the ticket. If this
    request is made to the VirtualCenter server, but the server does not provide
    the required service directly, then the server provides a hostname and port for
    a server that accepts the ticketed connection and provides the service.'''

    obj = vim.client.factory.create('{urn:vim25}HostServiceTicket')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 3:
        raise IndexError('Expected at least 4 arguments got: %d' % len(args))

    required = [ 'service', 'serviceVersion', 'sessionId' ]
    optional = [ 'host', 'port', 'sslThumbprint', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostConfigChangeMode = Enum(
    'modify',
    'replace',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.base.base_entity import BaseEntity

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class DiagnosticManager(BaseEntity):
    '''Provides an interface to get low-level debugging logs or diagnostic bundles for
    a server. For VirtualCenter, this includes the log files for the server daemon.
    For an ESX Server host, this includes detailed log files for the VMkernel.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.DiagnosticManager):
        super(DiagnosticManager, self).__init__(core, name=name, ref=ref, type=type)

    

    
    
    def BrowseDiagnosticLog(self, key, host=None, start=None, lines=None):
        '''Returns part of a log file. Log entries are always returned chronologically,
        typically with the newest event last.
        
        :param host: Specifies the host. If not specified, then it defaults to the default server. For example, if called on VirtualCenter, then the value defaults to VirtualCenter logs.
        
        :param key: A string key specifying the key for the log file to browse. Keys can be obtained using the queryDescriptions method.
        
        :param start: The line number for the first entry to be returned. If the parameter is not specified, then the operation returns with lines starting from the top of the log.
        
        :param lines: The number of lines to return. If not specified, then all lines are returned from the start value to the end of the file.
        
        '''
        return self.delegate("BrowseDiagnosticLog")(host, key, start, lines)
    
    def GenerateLogBundles_Task(self, includeDefault, host=None):
        '''Instructs the server to generate diagnostic bundles. A diagnostic bundle
        includes log files and other configuration information that can be used to
        investigate potential server issues. Virtual machine and guest operation system
        state is excluded from diagnostic bundles.
        
        :param includeDefault: Specifies if the bundle should include the default server. If called on a VirtualCenter server, then this means the VirtualCenter diagnostic files. If called directly on a host, then includeDefault must be set to true.
        
        :param host: Lists hosts that are included. This is only used when called on VirtualCenter. If called directly on a host, then this parameter must be empty.
        
        '''
        return self.delegate("GenerateLogBundles_Task")(includeDefault, host)
    
    def QueryDescriptions(self, host=None):
        '''Returns a list of diagnostic files for a given system.
        
        :param host: Specifies the host. If not specified, then it defaults to the server itself. For example, if called on VirtualCenter, then the value defaults to VirtualCenter logs. When called on an ESX server host, the host should not be specified.
        
        '''
        return self.delegate("QueryDescriptions")(host)



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HAErrorsAtDest(vim, *args, **kwargs):
    '''The destination compute resource is HA-enabled, and HA is not running properly.
    This will cause the following problems: 1) The VM will not have HA protection.
    2) If this is an intracluster VMotion, HA will not be properly informed that
    the migration completed. This can have serious consequences to the functioning
    of HA.'''

    obj = vim.client.factory.create('{urn:vim25}HAErrorsAtDest')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 4:
        raise IndexError('Expected at least 5 arguments got: %d' % len(args))

    required = [ 'dynamicProperty', 'dynamicType', 'faultCause', 'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

GuestOsDescriptorFirmwareType = Enum(
    'bios',
    'efi',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.distributed_virtual_switch import DistributedVirtualSwitch

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class VmwareDistributedVirtualSwitch(DistributedVirtualSwitch):
    '''The interface to the VMware implementation of the switch. The functionality
    listed here is for VMware DistributedVirtualSwitch only.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.VmwareDistributedVirtualSwitch):
        super(VmwareDistributedVirtualSwitch, self).__init__(core, name=name, ref=ref, type=type)

    

    



import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def SuspendedRelocateNotSupported(vim, *args, **kwargs):
    '''Either the source host product or the destination host product does not support
    relocation of suspended VMs. It must be supported on both, in order for the
    relocation to succeed. This fault is only applicable to suspended virtual
    machines.'''

    obj = vim.client.factory.create('{urn:vim25}SuspendedRelocateNotSupported')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 4:
        raise IndexError('Expected at least 5 arguments got: %d' % len(args))

    required = [ 'dynamicProperty', 'dynamicType', 'faultCause', 'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




from pyvisdk.esxcli.executer import execute_soap
from pyvisdk.esxcli.base import Base

class StorageVmfsExtent(Base):
    '''
    Manage VMFS extents.
    '''
    moid = 'ha-cli-handler-storage-vmfs-extent'
    def list(self):
        '''
        List the VMFS extents available on the host.
        :returns: vim.EsxCLI.storage.vmfs.extent.list.FilesystemVMFSExtents[]
        '''
        return execute_soap(self._client, self._host, self.moid, 'vim.EsxCLI.storage.vmfs.extent.List',
                            )   



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VmwareDistributedVirtualSwitchPvlanPortType = Enum(
    'community',
    'isolated',
    'promiscuous',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.sms_provider import SmsProvider

import logging

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

class VasaProvider(SmsProvider):
    '''VASA(vStorage APIs for Storage Awareness) provider definition.'''

    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.VasaProvider):
        super(VasaProvider, self).__init__(core, name=name, ref=ref, type=type)

    

    
    
    def VasaProviderSync_Task(self, arrayId):
        '''Issue a sync for the given Storage Array.
        
        :param arrayId: 
        
        '''
        return self.delegate("VasaProviderSync_Task")(arrayId)



########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

HostSystemPowerState = Enum(
    'poweredOff',
    'poweredOn',
    'standBy',
    'unknown',

)




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostIpRouteConfig(vim, *args, **kwargs):
    '''IP Route Configuration. All IPv4 addresses, subnet addresses, and netmasks are
    specified as strings using dotted decimal notation. For example, "192.0.2.1".
    IPv6 addresses are 128-bit addresses represented as eight fields of up to four
    hexadecimal digits. A colon separates each field (:). For example,
    2001:DB8:101::230:6eff:fe04:d9ff. The address can also consist of symbol '::'
    to represent multiple 16-bit groups of contiguous 0's only once in an address
    as described in RFC 2373.'''

    obj = vim.client.factory.create('{urn:vim25}HostIpRouteConfig')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 0:
        raise IndexError('Expected at least 1 arguments got: %d' % len(args))

    required = [  ]
    optional = [ 'defaultGateway', 'gatewayDevice', 'ipV6DefaultGateway', 'ipV6GatewayDevice',
        'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VmShutdownOnIsolationEventOperation = Enum(
    'poweredOff',
    'shutdown',

)




from pyvisdk.base.managed_object_types import ManagedObjectTypes

from pyvisdk.mo.managed_entity import ManagedEntity

import logging

log = logging.getLogger(__name__)

# This module is NOT auto-generated
# Inspired by decompiled Java classes from vCenter's internalvim25stubs.jar
# Unless states otherside, the methods and attributes were not used by esxcli,
# and thus not tested

class InternalDynamicTypeManager(ManagedEntity):
    def __init__(self, core, name=None, ref=None, type=ManagedObjectTypes.InternalDynamicTypeManager):
        super(InternalDynamicTypeManager, self).__init__(core, name=name, ref=ref, type=type)

    def DynamicTypeMgrQueryTypeInfo(self, filterSpec):
        return self.delegate("DynamicTypeMgrQueryTypeInfo")(filterSpec)

    def DynamicTypeMgrQueryMoInstances(self, filterSpec):
        return self.delegate("DynamicTypeMgrQueryMoInstances")(filterSpec)




########################################
# Automatically generated, do not edit.
########################################


from pyvisdk.thirdparty import Enum

VirtualEthernetCardMacType = Enum(
    'assigned',
    'generated',
    'manual',

)
